# TOAR II Database

### Models



#### Contact

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| person | [Person](#person) | A contact is either a person or an organisation | Yes |
| organisation | [Organisation](#organisation) | A contact is either a person or an organisation | Yes |

#### Coordinates

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| lat | number | longitude coordinate of station (decimal degrees_east). This is our best estimate of the station location which is not always identical to the official station coordinates (see potential changelog entry). | No |
| lng | number | latitude coordinate of station (decimal degrees_north). This is our best estimate of the station location which is not always identical to the official station coordinates (see potential changelog entry). | No |
| alt | number | altitude of station (in m above sea level). This is our best estimate of the station altitude, which is not always identical to the reported station altitude, but frequently uses the elevation from google earth instead (see potential changelog entry). | No |

#### Data

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| datetime | dateTime | date and time of observation | Yes |
| value | number | variable value at datetime | Yes |
| flags | string | flags | Yes |
| version | string | version | Yes |
| timeseries_id | integer | ID of timeseries | Yes |

#### Organisation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| name | string | Short name (abbreviation) of organisation | Yes |
| longname | string | Long name of organisation | Yes |
| kind | string | Kind of organisation | Yes |
| city | string | City where organisation resides | Yes |
| postcode | string | Postcode of organisation city | Yes |
| street_address | string | Street address of organisation city | Yes |
| country | string | Country to which organisation belongs | Yes |
| homepage | string | Homepage of organisation | Yes |

#### Person

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| name | string | Name of person | Yes |
| email | string | Email address of person | Yes |
| phone | string | Phone number of person | Yes |
| isprivate | boolean | Set this flag to true if the contact details shall not be exposed publicly | Yes |

#### Stationmeta

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| codes | [ string ] | list of station's codes | Yes |
| name | string | Station name for use in TOAR; normally equal to data provider’s name | Yes |
| coordinates | [Coordinates](#coordinates) | Best estimate of station latitude, longitude and altitude | Yes |
| coordinate_validation_status | string | Flag indicating whether the location of a station has been verified | Yes |
| country | string | The country, where the station resides, or which operates the station (e.g. in Antarctica) | Yes |
| state | string | The state or province, where the station resides | Yes |
| type_of_environment | string | Type of station | Yes |
| type_of_area | string | Type of station area | Yes |
| timezone | string | Station timezone | Yes |
| additional_metadata | string (json-string) | Any additional metadata about the station as a JSON data structure | Yes |
| roles | [ [StationmetaRole](#stationmetarole) ] |  | No |
| annotations | [ [StationmetaAnnotation](#stationmetaannotation) ] |  | No |
| aux_images | [ [StationmetaAuxImage](#stationmetaauximage) ] |  | No |
| aux_docs | [ [StationmetaAuxDoc](#stationmetaauxdoc) ] |  | No |
| aux_urls | [ [StationmetaAuxUrl](#stationmetaauxurl) ] |  | No |
| globalmeta | [StationmetaGlobal](#stationmetaglobal) |  | No |
| changelog | [ [StationmetaChangelog](#stationmetachangelog) ] |  | No |

#### StationmetaAnnotation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| kind | integer | kind of annotation (see controlled vocabulary: Kind Of Annotations) | Yes |
| text | string | text of annotation | Yes |
| date_added | dateTime | timestamp when annotation was added | Yes |
| approved | boolean | Flag indicating whether the annotation of a station has been verified | Yes |
| contributor_id | integer | ID of contributor who added the annotation | Yes |

#### StationmetaAuxDoc

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| resource_description | string | Description of the resource | Yes |
| date_added | dateTime | Date of metadata record entry into TOAR database | Yes |
| resource | string | auxillary document file | Yes |
| station_id | integer | internal station_id to which this resource belongs | Yes |

#### StationmetaAuxImage

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| resource_description | string | Description of the resource | Yes |
| date_added | dateTime | Date of metadata record entry into TOAR database | Yes |
| resource | string | auxillary image file | Yes |
| image_height | integer |  | Yes |
| image_width | integer |  | Yes |
| station_id | integer | internal station_id to which this resource belongs | Yes |

#### StationmetaAuxUrl

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| resource_description | string | Description of the resource | Yes |
| date_added | dateTime | Date of metadata record entry into TOAR database | Yes |
| resource | string | URL | Yes |
| station_id | integer | internal station_id to which this resource belongs | Yes |

#### StationmetaChangelog

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| datetime | dateTime | Date of change to the TOAR database | Yes |
| description | string | Description of change | Yes |
| old_value | string | value that has been changed in the TOAR database | Yes |
| new_value | string | new, changed value | Yes |
| station_id | integer | internal ID of station to which this change belongs | Yes |
| author_id | integer | internal ID of person who submitted the change to the TOAR database | Yes |
| type_of_change | integer | Type of change (see controlled vocabulary: Type Of Change) | Yes |

#### StationmetaCore

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| codes | [ string ] | list of station's codes | Yes |
| name | string | Station name for use in TOAR; normally equal to data provider’s name | Yes |
| coordinates | [Coordinates](#coordinates) | Best estimate of station latitude, longitude and altitude | Yes |
| coordinate_validation_status | string | Flag indicating whether the location of a station has been verified | Yes |
| country | string | The country, where the station resides, or which operates the station (e.g. in Antarctica) | Yes |
| state | string | The state or province, where the station resides | Yes |
| type_of_environment | string | Type of station | Yes |
| type_of_area | string | Type of station area | Yes |
| timezone | string | Station timezone | Yes |
| additional_metadata | string (json-string) | Any additional metadata about the station as a JSON data structure | Yes |

#### StationmetaCoreBase

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | No |
| codes | [ string ] | list of station's codes | Yes |
| name | string | Station name for use in TOAR; normally equal to data provider’s name | Yes |
| coordinates | [Coordinates](#coordinates) | Best estimate of station latitude, longitude and altitude | Yes |
| coordinate_validation_status | string | Flag indicating whether the location of a station has been verified | Yes |
| country | string | The country, where the station resides, or which operates the station (e.g. in Antarctica) | Yes |
| state | string | The state or province, where the station resides | Yes |
| type_of_environment | string | Type of station | Yes |
| type_of_area | string | Type of station area | Yes |
| timezone | string | Station timezone | Yes |
| additional_metadata | string (json-string) | Any additional metadata about the station as a JSON data structure | Yes |

#### StationmetaGlobal

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| population_density_year2010 | number | human population per square km for the year 2010 | Yes |
| max_population_density_25km_year2010 | number | Year 2010 maximum population density within a radius of 25 km around station location (residents km-2) | Yes |
| climatic_zone | string | Climatic zone according to IPCC, 2006. Data from European Soil Data Centre at JRC, Ispra, Italy | Yes |
| nightlight_1km_year2013 | number | Year 2013 nighttime lights brightness values at station location (original 1 km horizontal resolution). Reference: NOAA DMSP stable nighttime lights: a 0.925 km resolution dataset of non-ephemeral visible light intensity at night (Dataset: http://ngdc.noaa.gov/eog/dmsp/downloadV4composites.html) | Yes |
| nightlight_5km_year2013 | number | Nighttime lights brightness values for the year 2013 at 5 km resolution (original 1 km horizontal resolution) | Yes |
| max_nightlight_25km_year2013 | number | Maximum nighttime lights brightness values for the year 2013 at 25 km resolution (original 1 km horizontal resolution) | Yes |
| wheat_production_year2000 | number | Wheat production year2000. Y2000 wheat production amount at station location (units: thousand tons). (Reference: Dataset: http://gaez.fao.org/Main.html) | Yes |
| rice_production_year2000 | number | Y2000 rice production amount at station location (units: thousand tons) (Reference: Dataset: http://gaez.fao.org/Main.html) | Yes |
| edgar_htap_v2_nox_emissions_year2010 | number | EDGAR emissions inventory for nitrogen oxides (NOx) at 0.1° resolution (Reference: Janssens-Maenhout et al., 2015: http://edgar.jrc.ec.europa.eu/htap_v2/index.php?SECURE=123) | Yes |
| omi_no2_column_years2011to2015 | number | Average Y2011-Y2015 tropospheric NO2 columns from OMI at 0.1 degree resolution in units of 10^15 molecules cm-2 (Reference: Krotkov et al., 2016: (no public download)) | Yes |
| htap_region_tier1 | string | The integer denoting the 'tier1' region defined in the task force on hemispheric transport of air pollution (TFHTAP) coordinated model studies | Yes |
| etopo_alt | number | Global digital elevation model from diverse global and regional datasets in 1 arc minute resolution (Reference: Amante and Eakins, 2009: https://www.ngdc.noaa.gov/mgg/global/global.html) | Yes |
| etopo_min_alt_5km | number | Minimum elevation from the ETOPO1 dataset in an area of 5 km radius around the station location. This can be used to find out if a high altitude station is located in mountaineous terrain or on a plateau (see etopo_relative_alt) | Yes |
| etopo_relative_alt | number | Station elevation above the surrounding area. Derived by subtracting the minimum altitude within a 5 km radius around the station location from the actual station altitude | Yes |
| dominant_landcover_year2012 | string | The dominant IGBP landcover classification at the station location extracted from the MODIS MCD12C1 dataset (3 arc minutes resolution of the year 2012). (Dataset: https://lpdaac.usgs.gov/dataset_discovery/modis/modis_products_table/mcd12c1) | Yes |
| toar1_category | string | The station classification for the Tropsopheric Ozone Assessment Report based on the station proxy data that are stored in the TOAR database | Yes |
| station_id | integer | internal station_id to which these global data belong | Yes |

#### StationmetaRole

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| role | string | Role of contact (see controlled vocabulary: Role Codes) | Yes |
| status | string | Status of contact (see controlled vocabulary: Role Status) | Yes |
| contact_id | integer | to be deleted | Yes |
| contact | [Contact](#contact) | Contact for this role | Yes |

#### Timeseries

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| label | string | a short string to distinguish this timeseries from others with the same combination of station and variable | Yes |
| order | integer | indicates position of this timeseries in a list when several timeseries share the same station and variable combination | Yes |
| access_rights | string | Access rights of timeseries data | Yes |
| sampling_frequency | string | Sampling frequency of data in this timeseries | Yes |
| aggregation | string | Aggregation type in this timeseries | Yes |
| source | string |  | Yes |
| data_start_date | dateTime | Start date of the variable data available for this station | Yes |
| data_end_date | dateTime | End date of the variable data available for this station | Yes |
| measurement_method | string | instrument principle of measurement | Yes |
| sampling_height | number | Height above the ground of the inlet/instrument/sampler (in m) | Yes |
| date_added | dateTime | Date of timeseries metadata entry into TOAR database | Yes |
| date_modified | dateTime | Date of last timeseries metadata modification | Yes |
| additional_metadata | string (json-string) |  | No |
| station | [StationmetaCoreBase](#stationmetacorebase) |  | Yes |
| variable | [Variable](#variable) |  | Yes |
| programme | [TimeseriesProgramme](#timeseriesprogramme) |  | Yes |
| roles | [ [TimeseriesRole](#timeseriesrole) ] |  | No |
| annotations | [ [TimeseriesAnnotation](#timeseriesannotation) ] |  | No |
| changelog | [ [TimeseriesChangelog](#timeserieschangelog) ] |  | No |

#### TimeseriesAnnotation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| kind | integer | kind of annotation (see controlled vocabulary: Kind Of Annotations) | Yes |
| text | string | text of annotation | Yes |
| date_added | dateTime | timestamp when annotation was added | Yes |
| approved | boolean | Flag indicating whether the annotation of a time-series has been verified | Yes |
| contributor_id | integer | ID of contributor who added the annotation | Yes |
| timeseries_id | integer | internal timeseries_id to which this annotation belongs | Yes |

#### TimeseriesChangelog

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| datetime | dateTime | Date of change to the TOAR database | Yes |
| description | string | Description of change | Yes |
| old_value | string | value that has been changed in the TOAR database | Yes |
| new_value | string | new, changed value | Yes |
| timeseries_id | integer | internal ID of time-series to which this change belongs | Yes |
| author_id | integer | internal ID of person who submitted the change to the TOAR database | Yes |
| type_of_change | integer | Type of change (see controlled vocabulary: Type Of Change) | Yes |
| period_start | dateTime | for changes on data: start date from which changes were applied | No |
| period_end | dateTime | for changes on data: end date to which changes were applied | No |
| version | string | version that results from this change | No |

#### TimeseriesProgramme

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| name | string | (Short) name of programme | Yes |
| longname | string | (Long) name of programme | Yes |
| homepage | string | Homepage (URL) of programme | Yes |
| description | string | Description of programme | Yes |

#### TimeseriesRole

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer | for internal use only | Yes |
| role | string | Role of contact (see controlled vocabulary: Role Codes) | Yes |
| status | string | Status of contact (see controlled vocabulary: Role Status) | Yes |
| contact | [Contact](#contact) | Contact for this role | Yes |

#### Variable

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| name | string | Name. Short variable-like name of the variable | Yes |
| longname | string | Longname. Long (explicit) name of the variable | Yes |
| displayname | string | Displayname. Display name of the variable | Yes |
| cf_standardname | string | Cf standardname. CF standard name of the variable if defined | Yes |
| units | string | Units. Physical units of variable | Yes |
| chemical_formula | string | Chemical formula. Chemical formula of variable(if applicable) | Yes |
| id | integer |  | Yes |

## controlled vocabulary

#### Role Codes ####
  * Role Codes: [  
 [0, 'PointOfContact', 'point of contact'],  
 [1, 'PrincipalInvestigator', 'principal investigator'],  
 [2, 'Originator', 'originator'],  
 [3, 'Contributor', 'contributor'],  
 [4, 'Collaborator', 'collaborator'],  
 [5, 'ResourceProvider', 'resource provider']]
#### Role Status ####
  * Role Status: [  
 [0, 'active', 'active'],  
 [1, 'inactive', 'inactive'],  
 [2, 'unknown', 'unknown']]
#### Kind Of Annotations ####
  * Kind of Annotations: [  
 [0, 'User', 'user comment'],  
 [1, 'Provider', 'provider comment']]
#### Kind Of Organizations ####
  * Kind of Organizations: [  
 [1, 'Government', 'government'],  
 [2, 'Research', 'research'],  
 [8, 'Other', 'other'],  
 [7, 'Individual', 'individual'],  
 [6, 'Commercial', 'commercial'],  
 [5, 'NonProfit', 'non-profit'],  
 [4, 'International', 'international'],  
 [3, 'University', 'university']]
#### Data Access Rights ####
  * Data Access Rights: [  
 [0, 'ByAttribution', 'by attribution'],  
 [1, 'ShareAlike', 'share alike'],  
 [2, 'Restricted', 'restricted']]
#### Sampling Frequencies ####
  * Sampling Frequencies: [  
 [0, 'Hourly', 'hourly'],  
 [1, 'ThreeHourly', '3-hourly'],  
 [2, 'SixHourly', '6-hourly'],  
 [3, 'Daily', 'daily'],  
 [4, 'Weekly', 'weekly'],  
 [5, 'Monthly', 'monthly'],  
 [6, 'Yearly', 'yearly'],  
 [7, 'Irregular', 'irregular data samples of constant length'],  
 [8, 'Irregular2', 'irregular data samples of varying length']]
#### Aggregation Types ####
  * Aggregation Types: [  
 [0, 'Mean', 'mean'],  
 [1, 'Mean1Of2', 'mean of two values'],  
 [2, 'Mean1OfWeek', 'weekly mean'],  
 [3, 'Mean4Samples', 'mean out of 4 samples'],  
 [4, 'MeanMonth', 'monthly mean'],  
 [5, 'None', 'none'],  
 [6, 'Unknown', 'unknown']]
#### Data Sources ####
  * Data Sources: [  
 [0, 'Model', 'model'],  
 [1, 'Measurement', 'measurement']]
#### Measurement Methods ####
  * Measurement Methods: [  
 [0, 'UVAbsorption', 'UV absorption'],  
 [1, 'UnknownInstrument', 'unknown instrument']]
#### Climatic Zones ####
  * Climatic Zones: [  
 [-1, 'Undefined', 'undefined'],  
 [0, 'Unclassified', 'unclassified'],  
 [1, 'WarmTemperateMoist', 'warm temperate moist'],  
 [2, 'WarmTemperateDry', 'warm temperate dry'],  
 [3, 'CoolTemperateMoist', 'cool temperate moist'],  
 [4, 'CoolTemperateDry', 'cool temperate dry'],  
 [5, 'PolarMoist', 'polar moist'],  
 [6, 'PolarDry', 'polar dry'],  
 [7, 'BorealMoist', 'boreal moist'],  
 [8, 'BorealDry', 'boreal dry'],  
 [9, 'TropicalMontane', 'tropical montane'],  
 [10, 'TropicalWet', 'tropical wet'],  
 [11, 'TropicalMoist', 'tropical moist'],  
 [12, 'TropicalDry', 'tropical dry']]
#### Coordinate Validity ####
  * Coordinate Validity: [  
 [0, 'NotChecked', 'not checked'],  
 [1, 'Verified', 'verified'],  
 [2, 'Plausible', 'plausible'],  
 [3, 'Doubtful', 'doubtful'],  
 [4, 'Unverifyable', 'not verifyable']]
#### Countries ####
  * Countries: [  
 [0, 'AF', 'Afghanistan'],  
 [1, 'AX', 'Åland Islands'],  
 [2, 'AL', 'Albania'],  
 [3, 'DZ', 'Algeria'],  
 [4, 'AS', 'American Samoa'],  
 [5, 'AD', 'Andorra'],  
 [6, 'AO', 'Angola'],  
 [7, 'AI', 'Anguilla'],  
 [8, 'AQ', 'Antarctica'],  
 [9, 'AG', 'Antigua and Barbuda'],  
 [10, 'AR', 'Argentina'],  
 [11, 'AM', 'Armenia'],  
 [12, 'AW', 'Aruba'],  
 [13, 'AU', 'Australia'],  
 [14, 'AT', 'Austria'],  
 [15, 'AZ', 'Azerbaijan'],  
 [16, 'BS', 'Bahamas'],  
 [17, 'BH', 'Bahrain'],  
 [18, 'BD', 'Bangladesh'],  
 [19, 'BB', 'Barbados'],  
 [20, 'BY', 'Belarus'],  
 [21, 'BE', 'Belgium'],  
 [22, 'BZ', 'Belize'],  
 [23, 'BJ', 'Benin'],  
 [24, 'BM', 'Bermuda'],  
 [25, 'BT', 'Bhutan'],  
 [26, 'BO', 'Plurinational State of Bolivia'],  
 [27, 'BQ', 'Bonaire, Sint Eustatius and Saba'],  
 [28, 'BA', 'Bosnia and Herzegovina'],  
 [29, 'BW', 'Botswana'],  
 [30, 'BV', 'Bouvet Island'],  
 [31, 'BR', 'Brazil'],  
 [32, 'IO', 'British Indian Ocean Territory'],  
 [33, 'UM', 'United States Minor Outlying Islands'],  
 [34, 'VG', 'British Virgin Islands'],  
 [35, 'VI', 'U.S. Virgin Islands'],  
 [36, 'BN', 'Brunei Darussalam'],  
 [37, 'BG', 'Bulgaria'],  
 [38, 'BF', 'Burkina Faso'],  
 [39, 'BI', 'Burundi'],  
 [40, 'KH', 'Cambodia'],  
 [41, 'CM', 'Cameroon'],  
 [42, 'CA', 'Canada'],  
 [43, 'CV', 'Cabo Verde'],  
 [44, 'KY', 'Cayman Islands'],  
 [45, 'CF', 'Central African Republic'],  
 [46, 'TD', 'Chad'],  
 [47, 'CL', 'Chile'],  
 [48, 'CN', 'China'],  
 [49, 'CX', 'Christmas Island'],  
 [50, 'CC', 'Cocos (Keeling) Islands'],  
 [51, 'CO', 'Colombia'],  
 [52, 'KM', 'Comoros'],  
 [53, 'CG', 'Congo'],  
 [54, 'CD', 'Democratic Republic of the Congo'],  
 [55, 'CK', 'Cook Islands'],  
 [56, 'CR', 'Costa Rica'],  
 [57, 'HR', 'Croatia'],  
 [58, 'CU', 'Cuba'],  
 [59, 'CW', 'Curaçao'],  
 [60, 'CY', 'Cyprus'],  
 [61, 'CZ', 'Czech Republic'],  
 [62, 'DK', 'Denmark'],  
 [63, 'DJ', 'Djibouti'],  
 [64, 'DM', 'Dominica'],  
 [65, 'DO', 'Dominican Republic'],  
 [66, 'EC', 'Ecuador'],  
 [67, 'EG', 'Egypt'],  
 [68, 'SV', 'El Salvador'],  
 [69, 'GQ', 'Equatorial Guinea'],  
 [70, 'ER', 'Eritrea'],  
 [71, 'EE', 'Estonia'],  
 [72, 'ET', 'Ethiopia'],  
 [73, 'FK', 'Falkland Islands (Malvinas)'],  
 [74, 'FO', 'Faroe Islands'],  
 [75, 'FJ', 'Fiji'],  
 [76, 'FI', 'Finland'],  
 [77, 'FR', 'France'],  
 [78, 'GF', 'French Guiana'],  
 [79, 'PF', 'French Polynesia'],  
 [80, 'TF', 'French Southern Territories'],  
 [81, 'GA', 'Gabon'],  
 [82, 'GM', 'Gambia'],  
 [83, 'GE', 'Georgia'],  
 [84, 'DE', 'Germany'],  
 [85, 'GH', 'Ghana'],  
 [86, 'GI', 'Gibraltar'],  
 [87, 'GR', 'Greece'],  
 [88, 'GL', 'Greenland'],  
 [89, 'GD', 'Grenada'],  
 [90, 'GP', 'Guadeloupe'],  
 [91, 'GU', 'Guam'],  
 [92, 'GT', 'Guatemala'],  
 [93, 'GG', 'Guernsey'],  
 [94, 'GN', 'Guinea'],  
 [95, 'GW', 'Guinea-Bissau'],  
 [96, 'GY', 'Guyana'],  
 [97, 'HT', 'Haiti'],  
 [98, 'HM', 'Heard Island and McDonald Islands'],  
 [99, 'VA', 'Holy See'],  
 [100, 'HN', 'Honduras'],  
 [101, 'HK', 'Hong Kong'],  
 [102, 'HU', 'Hungary'],  
 [103, 'IS', 'Iceland'],  
 [104, 'IN', 'India'],  
 [105, 'ID', 'Indonesia'],  
 [106, 'CI', "Côte d'Ivoire"],  
 [107, 'IR', 'Islamic Republic of Iran'],  
 [108, 'IQ', 'Iraq'],  
 [109, 'IE', 'Ireland'],  
 [110, 'IM', 'Isle of Man'],  
 [111, 'IL', 'Israel'],  
 [112, 'IT', 'Italy'],  
 [113, 'JM', 'Jamaica'],  
 [114, 'JP', 'Japan'],  
 [115, 'JE', 'Jersey'],  
 [116, 'JO', 'Jordan'],  
 [117, 'KZ', 'Kazakhstan'],  
 [118, 'KE', 'Kenya'],  
 [119, 'KI', 'Kiribati'],  
 [120, 'KW', 'Kuwait'],  
 [121, 'KG', 'Kyrgyzstan'],  
 [122, 'LA', "Lao People's Democratic Republic"],  
 [123, 'LV', 'Latvia'],  
 [124, 'LB', 'Lebanon'],  
 [125, 'LS', 'Lesotho'],  
 [126, 'LR', 'Liberia'],  
 [127, 'LY', 'Libya'],  
 [128, 'LI', 'Liechtenstein'],  
 [129, 'LT', 'Lithuania'],  
 [130, 'LU', 'Luxembourg'],  
 [131, 'MO', 'Macao'],  
 [132, 'MK', 'North Macedonia'],  
 [133, 'MG', 'Madagascar'],  
 [134, 'MW', 'Malawi'],  
 [135, 'MY', 'Malaysia'],  
 [136, 'MV', 'Maldives'],  
 [137, 'ML', 'Mali'],  
 [138, 'MT', 'Malta'],  
 [139, 'MH', 'Marshall Islands'],  
 [140, 'MQ', 'Martinique'],  
 [141, 'MR', 'Mauritania'],  
 [142, 'MU', 'Mauritius'],  
 [143, 'YT', 'Mayotte'],  
 [144, 'MX', 'Mexico'],  
 [145, 'FM', 'Federated States of Micronesia'],  
 [146, 'MD', 'Republic of Moldova'],  
 [147, 'MC', 'Monaco'],  
 [148, 'MN', 'Mongolia'],  
 [149, 'ME', 'Montenegro'],  
 [150, 'MS', 'Montserrat'],  
 [151, 'MA', 'Morocco'],  
 [152, 'MZ', 'Mozambique'],  
 [153, 'MM', 'Myanmar'],  
 [154, 'NA', 'Namibia'],  
 [155, 'NR', 'Nauru'],  
 [156, 'NP', 'Nepal'],  
 [157, 'NL', 'Netherlands'],  
 [158, 'NC', 'New Caledonia'],  
 [159, 'NZ', 'New Zealand'],  
 [160, 'NI', 'Nicaragua'],  
 [161, 'NE', 'Niger'],  
 [162, 'NG', 'Nigeria'],  
 [163, 'NU', 'Niue'],  
 [164, 'NF', 'Norfolk Island'],  
 [165, 'KP', "Democratic People's Republic of Korea"],  
 [166, 'MP', 'Northern Mariana Islands'],  
 [167, 'NO', 'Norway'],  
 [168, 'OM', 'Oman'],  
 [169, 'PK', 'Pakistan'],  
 [170, 'PW', 'Palau'],  
 [171, 'PS', 'State of Palestine'],  
 [172, 'PA', 'Panama'],  
 [173, 'PG', 'Papua New Guinea'],  
 [174, 'PY', 'Paraguay'],  
 [175, 'PE', 'Peru'],  
 [176, 'PH', 'Philippines'],  
 [177, 'PN', 'Pitcairn'],  
 [178, 'PL', 'Poland'],  
 [179, 'PT', 'Portugal'],  
 [180, 'PR', 'Puerto Rico'],  
 [181, 'QA', 'Qatar'],  
 [182, 'XK', 'Republic of Kosovo'],  
 [183, 'RE', 'Réunion'],  
 [184, 'RO', 'Romania'],  
 [185, 'RU', 'Russian Federation'],  
 [186, 'RW', 'Rwanda'],  
 [187, 'BL', 'Saint Barthélemy'],  
 [188, 'SH', 'Saint Helena, Ascension and Tristan da Cunha'],  
 [189, 'KN', 'Saint Kitts and Nevis'],  
 [190, 'LC', 'Saint Lucia'],  
 [191, 'MF', 'Saint Martin (French part)'],  
 [192, 'PM', 'Saint Pierre and Miquelon'],  
 [193, 'VC', 'Saint Vincent and the Grenadines'],  
 [194, 'WS', 'Samoa'],  
 [195, 'SM', 'San Marino'],  
 [196, 'ST', 'Sao Tome and Principe'],  
 [197, 'SA', 'Saudi Arabia'],  
 [198, 'SN', 'Senegal'],  
 [199, 'RS', 'Serbia'],  
 [200, 'SC', 'Seychelles'],  
 [201, 'SL', 'Sierra Leone'],  
 [202, 'SG', 'Singapore'],  
 [203, 'SX', 'Sint Maarten (Dutch part)'],  
 [204, 'SK', 'Slovakia'],  
 [205, 'SI', 'Slovenia'],  
 [206, 'SB', 'Solomon Islands'],  
 [207, 'SO', 'Somalia'],  
 [208, 'ZA', 'South Africa'],  
 [209, 'GS', 'South Georgia and the South Sandwich Islands'],  
 [210, 'KR', 'Republic of Korea'],  
 [211, 'SS', 'South Sudan'],  
 [212, 'ES', 'Spain'],  
 [213, 'LK', 'Sri Lanka'],  
 [214, 'SD', 'Sudan'],  
 [215, 'SR', 'Suriname'],  
 [216, 'SJ', 'Svalbard and Jan Mayen'],  
 [217, 'SZ', 'Swaziland'],  
 [218, 'SE', 'Sweden'],  
 [219, 'CH', 'Switzerland'],  
 [220, 'SY', 'Syrian Arab Republic'],  
 [221, 'TW', 'Taiwan'],  
 [222, 'TJ', 'Tajikistan'],  
 [224, 'TH', 'Thailand'],  
 [225, 'TL', 'Timor-Leste'],  
 [226, 'TG', 'Togo'],  
 [227, 'TK', 'Tokelau'],  
 [228, 'TO', 'Tonga'],  
 [229, 'TT', 'Trinidad and Tobago'],  
 [230, 'TN', 'Tunisia'],  
 [231, 'TR', 'Turkey'],  
 [232, 'TM', 'Turkmenistan'],  
 [233, 'TC', 'Turks and Caicos Islands'],  
 [234, 'TV', 'Tuvalu'],  
 [235, 'UG', 'Uganda'],  
 [236, 'UA', 'Ukraine'],  
 [237, 'AE', 'United Arab Emirates'],  
 [238, 'GB', 'United Kingdom of Great Britain and Northern Ireland'],  
 [239, 'US', 'United States of America'],  
 [240, 'UY', 'Uruguay'],  
 [241, 'UZ', 'Uzbekistan'],  
 [242, 'VU', 'Vanuatu'],  
 [243, 'VE', 'Bolivarian Republic of Venezuela'],  
 [244, 'VN', 'Viet Nam'],  
 [245, 'WF', 'Wallis and Futuna'],  
 [246, 'EH', 'Western Sahara'],  
 [247, 'YE', 'Yemen'],  
 [248, 'ZM', 'Zambia'],  
 [249, 'ZW', 'Zimbabwe'],  
 [-1, 'N/A', 'N/A'],  
 [223, 'TZ', 'United Republic of Tanzania']]
#### Timezones ####
  * Timezones: [  
 [0, 'Africa/Abidjan', 'Africa/Abidjan'],  
 [1, 'Africa/Accra', 'Africa/Accra'],  
 [2, 'Africa/Addis_Ababa', 'Africa/Addis_Ababa'],  
 [3, 'Africa/Algiers', 'Africa/Algiers'],  
 [4, 'Africa/Asmara', 'Africa/Asmara'],  
 [5, 'Africa/Asmera', 'Africa/Asmera'],  
 [6, 'Africa/Bamako', 'Africa/Bamako'],  
 [7, 'Africa/Bangui', 'Africa/Bangui'],  
 [8, 'Africa/Banjul', 'Africa/Banjul'],  
 [9, 'Africa/Bissau', 'Africa/Bissau'],  
 [10, 'Africa/Blantyre', 'Africa/Blantyre'],  
 [11, 'Africa/Brazzaville', 'Africa/Brazzaville'],  
 [12, 'Africa/Bujumbura', 'Africa/Bujumbura'],  
 [13, 'Africa/Cairo', 'Africa/Cairo'],  
 [14, 'Africa/Casablanca', 'Africa/Casablanca'],  
 [15, 'Africa/Ceuta', 'Africa/Ceuta'],  
 [16, 'Africa/Conakry', 'Africa/Conakry'],  
 [17, 'Africa/Dakar', 'Africa/Dakar'],  
 [18, 'Africa/Dar_es_Salaam', 'Africa/Dar_es_Salaam'],  
 [19, 'Africa/Djibouti', 'Africa/Djibouti'],  
 [20, 'Africa/Douala', 'Africa/Douala'],  
 [21, 'Africa/El_Aaiun', 'Africa/El_Aaiun'],  
 [22, 'Africa/Freetown', 'Africa/Freetown'],  
 [23, 'Africa/Gaborone', 'Africa/Gaborone'],  
 [24, 'Africa/Harare', 'Africa/Harare'],  
 [25, 'Africa/Johannesburg', 'Africa/Johannesburg'],  
 [26, 'Africa/Juba', 'Africa/Juba'],  
 [27, 'Africa/Kampala', 'Africa/Kampala'],  
 [28, 'Africa/Khartoum', 'Africa/Khartoum'],  
 [29, 'Africa/Kigali', 'Africa/Kigali'],  
 [30, 'Africa/Kinshasa', 'Africa/Kinshasa'],  
 [31, 'Africa/Lagos', 'Africa/Lagos'],  
 [32, 'Africa/Libreville', 'Africa/Libreville'],  
 [33, 'Africa/Lome', 'Africa/Lome'],  
 [34, 'Africa/Luanda', 'Africa/Luanda'],  
 [35, 'Africa/Lubumbashi', 'Africa/Lubumbashi'],  
 [36, 'Africa/Lusaka', 'Africa/Lusaka'],  
 [37, 'Africa/Malabo', 'Africa/Malabo'],  
 [38, 'Africa/Maputo', 'Africa/Maputo'],  
 [39, 'Africa/Maseru', 'Africa/Maseru'],  
 [40, 'Africa/Mbabane', 'Africa/Mbabane'],  
 [41, 'Africa/Mogadishu', 'Africa/Mogadishu'],  
 [42, 'Africa/Monrovia', 'Africa/Monrovia'],  
 [43, 'Africa/Nairobi', 'Africa/Nairobi'],  
 [44, 'Africa/Ndjamena', 'Africa/Ndjamena'],  
 [45, 'Africa/Niamey', 'Africa/Niamey'],  
 [46, 'Africa/Nouakchott', 'Africa/Nouakchott'],  
 [47, 'Africa/Ouagadougou', 'Africa/Ouagadougou'],  
 [48, 'Africa/Porto-Novo', 'Africa/Porto-Novo'],  
 [49, 'Africa/Sao_Tome', 'Africa/Sao_Tome'],  
 [50, 'Africa/Timbuktu', 'Africa/Timbuktu'],  
 [51, 'Africa/Tripoli', 'Africa/Tripoli'],  
 [52, 'Africa/Tunis', 'Africa/Tunis'],  
 [53, 'Africa/Windhoek', 'Africa/Windhoek'],  
 [54, 'America/Adak', 'America/Adak'],  
 [55, 'America/Anchorage', 'America/Anchorage'],  
 [56, 'America/Anguilla', 'America/Anguilla'],  
 [57, 'America/Antigua', 'America/Antigua'],  
 [58, 'America/Araguaina', 'America/Araguaina'],  
 [59, 'America/Argentina/Buenos_Aires', 'America/Argentina/Buenos_Aires'],  
 [60, 'America/Argentina/Catamarca', 'America/Argentina/Catamarca'],  
 [61, 'America/Argentina/ComodRivadavia', 'America/Argentina/ComodRivadavia'],  
 [62, 'America/Argentina/Cordoba', 'America/Argentina/Cordoba'],  
 [63, 'America/Argentina/Jujuy', 'America/Argentina/Jujuy'],  
 [64, 'America/Argentina/La_Rioja', 'America/Argentina/La_Rioja'],  
 [65, 'America/Argentina/Mendoza', 'America/Argentina/Mendoza'],  
 [66, 'America/Argentina/Rio_Gallegos', 'America/Argentina/Rio_Gallegos'],  
 [67, 'America/Argentina/Salta', 'America/Argentina/Salta'],  
 [68, 'America/Argentina/San_Juan', 'America/Argentina/San_Juan'],  
 [69, 'America/Argentina/San_Luis', 'America/Argentina/San_Luis'],  
 [70, 'America/Argentina/Tucuman', 'America/Argentina/Tucuman'],  
 [71, 'America/Argentina/Ushuaia', 'America/Argentina/Ushuaia'],  
 [72, 'America/Aruba', 'America/Aruba'],  
 [73, 'America/Asuncion', 'America/Asuncion'],  
 [74, 'America/Atikokan', 'America/Atikokan'],  
 [75, 'America/Atka', 'America/Atka'],  
 [76, 'America/Bahia', 'America/Bahia'],  
 [77, 'America/Bahia_Banderas', 'America/Bahia_Banderas'],  
 [78, 'America/Barbados', 'America/Barbados'],  
 [79, 'America/Belem', 'America/Belem'],  
 [80, 'America/Belize', 'America/Belize'],  
 [81, 'America/Blanc-Sablon', 'America/Blanc-Sablon'],  
 [82, 'America/Boa_Vista', 'America/Boa_Vista'],  
 [83, 'America/Bogota', 'America/Bogota'],  
 [84, 'America/Boise', 'America/Boise'],  
 [85, 'America/Buenos_Aires', 'America/Buenos_Aires'],  
 [86, 'America/Cambridge_Bay', 'America/Cambridge_Bay'],  
 [87, 'America/Campo_Grande', 'America/Campo_Grande'],  
 [88, 'America/Cancun', 'America/Cancun'],  
 [89, 'America/Caracas', 'America/Caracas'],  
 [90, 'America/Catamarca', 'America/Catamarca'],  
 [91, 'America/Cayenne', 'America/Cayenne'],  
 [92, 'America/Cayman', 'America/Cayman'],  
 [93, 'America/Chicago', 'America/Chicago'],  
 [94, 'America/Chihuahua', 'America/Chihuahua'],  
 [95, 'America/Coral_Harbour', 'America/Coral_Harbour'],  
 [96, 'America/Cordoba', 'America/Cordoba'],  
 [97, 'America/Costa_Rica', 'America/Costa_Rica'],  
 [98, 'America/Creston', 'America/Creston'],  
 [99, 'America/Cuiaba', 'America/Cuiaba'],  
 [100, 'America/Curacao', 'America/Curacao'],  
 [101, 'America/Danmarkshavn', 'America/Danmarkshavn'],  
 [102, 'America/Dawson', 'America/Dawson'],  
 [103, 'America/Dawson_Creek', 'America/Dawson_Creek'],  
 [104, 'America/Denver', 'America/Denver'],  
 [105, 'America/Detroit', 'America/Detroit'],  
 [106, 'America/Dominica', 'America/Dominica'],  
 [107, 'America/Edmonton', 'America/Edmonton'],  
 [108, 'America/Eirunepe', 'America/Eirunepe'],  
 [109, 'America/El_Salvador', 'America/El_Salvador'],  
 [110, 'America/Ensenada', 'America/Ensenada'],  
 [111, 'America/Fort_Nelson', 'America/Fort_Nelson'],  
 [112, 'America/Fort_Wayne', 'America/Fort_Wayne'],  
 [113, 'America/Fortaleza', 'America/Fortaleza'],  
 [114, 'America/Glace_Bay', 'America/Glace_Bay'],  
 [115, 'America/Godthab', 'America/Godthab'],  
 [116, 'America/Goose_Bay', 'America/Goose_Bay'],  
 [117, 'America/Grand_Turk', 'America/Grand_Turk'],  
 [118, 'America/Grenada', 'America/Grenada'],  
 [119, 'America/Guadeloupe', 'America/Guadeloupe'],  
 [120, 'America/Guatemala', 'America/Guatemala'],  
 [121, 'America/Guayaquil', 'America/Guayaquil'],  
 [122, 'America/Guyana', 'America/Guyana'],  
 [123, 'America/Halifax', 'America/Halifax'],  
 [124, 'America/Havana', 'America/Havana'],  
 [125, 'America/Hermosillo', 'America/Hermosillo'],  
 [126, 'America/Indiana/Indianapolis', 'America/Indiana/Indianapolis'],  
 [127, 'America/Indiana/Knox', 'America/Indiana/Knox'],  
 [128, 'America/Indiana/Marengo', 'America/Indiana/Marengo'],  
 [129, 'America/Indiana/Petersburg', 'America/Indiana/Petersburg'],  
 [130, 'America/Indiana/Tell_City', 'America/Indiana/Tell_City'],  
 [131, 'America/Indiana/Vevay', 'America/Indiana/Vevay'],  
 [132, 'America/Indiana/Vincennes', 'America/Indiana/Vincennes'],  
 [133, 'America/Indiana/Winamac', 'America/Indiana/Winamac'],  
 [134, 'America/Indianapolis', 'America/Indianapolis'],  
 [135, 'America/Inuvik', 'America/Inuvik'],  
 [136, 'America/Iqaluit', 'America/Iqaluit'],  
 [137, 'America/Jamaica', 'America/Jamaica'],  
 [138, 'America/Jujuy', 'America/Jujuy'],  
 [139, 'America/Juneau', 'America/Juneau'],  
 [140, 'America/Kentucky/Louisville', 'America/Kentucky/Louisville'],  
 [141, 'America/Kentucky/Monticello', 'America/Kentucky/Monticello'],  
 [142, 'America/Knox_IN', 'America/Knox_IN'],  
 [143, 'America/Kralendijk', 'America/Kralendijk'],  
 [144, 'America/La_Paz', 'America/La_Paz'],  
 [145, 'America/Lima', 'America/Lima'],  
 [146, 'America/Los_Angeles', 'America/Los_Angeles'],  
 [147, 'America/Louisville', 'America/Louisville'],  
 [148, 'America/Lower_Princes', 'America/Lower_Princes'],  
 [149, 'America/Maceio', 'America/Maceio'],  
 [150, 'America/Managua', 'America/Managua'],  
 [151, 'America/Manaus', 'America/Manaus'],  
 [152, 'America/Marigot', 'America/Marigot'],  
 [153, 'America/Martinique', 'America/Martinique'],  
 [154, 'America/Matamoros', 'America/Matamoros'],  
 [155, 'America/Mazatlan', 'America/Mazatlan'],  
 [156, 'America/Mendoza', 'America/Mendoza'],  
 [157, 'America/Menominee', 'America/Menominee'],  
 [158, 'America/Merida', 'America/Merida'],  
 [159, 'America/Metlakatla', 'America/Metlakatla'],  
 [160, 'America/Mexico_City', 'America/Mexico_City'],  
 [161, 'America/Miquelon', 'America/Miquelon'],  
 [162, 'America/Moncton', 'America/Moncton'],  
 [163, 'America/Monterrey', 'America/Monterrey'],  
 [164, 'America/Montevideo', 'America/Montevideo'],  
 [165, 'America/Montreal', 'America/Montreal'],  
 [166, 'America/Montserrat', 'America/Montserrat'],  
 [167, 'America/Nassau', 'America/Nassau'],  
 [168, 'America/New_York', 'America/New_York'],  
 [169, 'America/Nipigon', 'America/Nipigon'],  
 [170, 'America/Nome', 'America/Nome'],  
 [171, 'America/Noronha', 'America/Noronha'],  
 [172, 'America/North_Dakota/Beulah', 'America/North_Dakota/Beulah'],  
 [173, 'America/North_Dakota/Center', 'America/North_Dakota/Center'],  
 [174, 'America/North_Dakota/New_Salem', 'America/North_Dakota/New_Salem'],  
 [175, 'America/Nuuk', 'America/Nuuk'],  
 [176, 'America/Ojinaga', 'America/Ojinaga'],  
 [177, 'America/Panama', 'America/Panama'],  
 [178, 'America/Pangnirtung', 'America/Pangnirtung'],  
 [179, 'America/Paramaribo', 'America/Paramaribo'],  
 [180, 'America/Phoenix', 'America/Phoenix'],  
 [181, 'America/Port-au-Prince', 'America/Port-au-Prince'],  
 [182, 'America/Port_of_Spain', 'America/Port_of_Spain'],  
 [183, 'America/Porto_Acre', 'America/Porto_Acre'],  
 [184, 'America/Porto_Velho', 'America/Porto_Velho'],  
 [185, 'America/Puerto_Rico', 'America/Puerto_Rico'],  
 [186, 'America/Punta_Arenas', 'America/Punta_Arenas'],  
 [187, 'America/Rainy_River', 'America/Rainy_River'],  
 [188, 'America/Rankin_Inlet', 'America/Rankin_Inlet'],  
 [189, 'America/Recife', 'America/Recife'],  
 [190, 'America/Regina', 'America/Regina'],  
 [191, 'America/Resolute', 'America/Resolute'],  
 [192, 'America/Rio_Branco', 'America/Rio_Branco'],  
 [193, 'America/Rosario', 'America/Rosario'],  
 [194, 'America/Santa_Isabel', 'America/Santa_Isabel'],  
 [195, 'America/Santarem', 'America/Santarem'],  
 [196, 'America/Santiago', 'America/Santiago'],  
 [197, 'America/Santo_Domingo', 'America/Santo_Domingo'],  
 [198, 'America/Sao_Paulo', 'America/Sao_Paulo'],  
 [199, 'America/Scoresbysund', 'America/Scoresbysund'],  
 [200, 'America/Shiprock', 'America/Shiprock'],  
 [201, 'America/Sitka', 'America/Sitka'],  
 [202, 'America/St_Barthelemy', 'America/St_Barthelemy'],  
 [203, 'America/St_Johns', 'America/St_Johns'],  
 [204, 'America/St_Kitts', 'America/St_Kitts'],  
 [205, 'America/St_Lucia', 'America/St_Lucia'],  
 [206, 'America/St_Thomas', 'America/St_Thomas'],  
 [207, 'America/St_Vincent', 'America/St_Vincent'],  
 [208, 'America/Swift_Current', 'America/Swift_Current'],  
 [209, 'America/Tegucigalpa', 'America/Tegucigalpa'],  
 [210, 'America/Thule', 'America/Thule'],  
 [211, 'America/Thunder_Bay', 'America/Thunder_Bay'],  
 [212, 'America/Tijuana', 'America/Tijuana'],  
 [213, 'America/Toronto', 'America/Toronto'],  
 [214, 'America/Tortola', 'America/Tortola'],  
 [215, 'America/Vancouver', 'America/Vancouver'],  
 [216, 'America/Virgin', 'America/Virgin'],  
 [217, 'America/Whitehorse', 'America/Whitehorse'],  
 [218, 'America/Winnipeg', 'America/Winnipeg'],  
 [219, 'America/Yakutat', 'America/Yakutat'],  
 [220, 'America/Yellowknife', 'America/Yellowknife'],  
 [221, 'Antarctica/Casey', 'Antarctica/Casey'],  
 [222, 'Antarctica/Davis', 'Antarctica/Davis'],  
 [223, 'Antarctica/DumontDUrville', 'Antarctica/DumontDUrville'],  
 [224, 'Antarctica/Macquarie', 'Antarctica/Macquarie'],  
 [225, 'Antarctica/Mawson', 'Antarctica/Mawson'],  
 [226, 'Antarctica/McMurdo', 'Antarctica/McMurdo'],  
 [227, 'Antarctica/Palmer', 'Antarctica/Palmer'],  
 [228, 'Antarctica/Rothera', 'Antarctica/Rothera'],  
 [229, 'Antarctica/South_Pole', 'Antarctica/South_Pole'],  
 [230, 'Antarctica/Syowa', 'Antarctica/Syowa'],  
 [231, 'Antarctica/Troll', 'Antarctica/Troll'],  
 [232, 'Antarctica/Vostok', 'Antarctica/Vostok'],  
 [233, 'Arctic/Longyearbyen', 'Arctic/Longyearbyen'],  
 [234, 'Asia/Aden', 'Asia/Aden'],  
 [235, 'Asia/Almaty', 'Asia/Almaty'],  
 [236, 'Asia/Amman', 'Asia/Amman'],  
 [237, 'Asia/Anadyr', 'Asia/Anadyr'],  
 [238, 'Asia/Aqtau', 'Asia/Aqtau'],  
 [239, 'Asia/Aqtobe', 'Asia/Aqtobe'],  
 [240, 'Asia/Ashgabat', 'Asia/Ashgabat'],  
 [241, 'Asia/Ashkhabad', 'Asia/Ashkhabad'],  
 [242, 'Asia/Atyrau', 'Asia/Atyrau'],  
 [243, 'Asia/Baghdad', 'Asia/Baghdad'],  
 [244, 'Asia/Bahrain', 'Asia/Bahrain'],  
 [245, 'Asia/Baku', 'Asia/Baku'],  
 [246, 'Asia/Bangkok', 'Asia/Bangkok'],  
 [247, 'Asia/Barnaul', 'Asia/Barnaul'],  
 [248, 'Asia/Beirut', 'Asia/Beirut'],  
 [249, 'Asia/Bishkek', 'Asia/Bishkek'],  
 [250, 'Asia/Brunei', 'Asia/Brunei'],  
 [251, 'Asia/Calcutta', 'Asia/Calcutta'],  
 [252, 'Asia/Chita', 'Asia/Chita'],  
 [253, 'Asia/Choibalsan', 'Asia/Choibalsan'],  
 [254, 'Asia/Chongqing', 'Asia/Chongqing'],  
 [255, 'Asia/Chungking', 'Asia/Chungking'],  
 [256, 'Asia/Colombo', 'Asia/Colombo'],  
 [257, 'Asia/Dacca', 'Asia/Dacca'],  
 [258, 'Asia/Damascus', 'Asia/Damascus'],  
 [259, 'Asia/Dhaka', 'Asia/Dhaka'],  
 [260, 'Asia/Dili', 'Asia/Dili'],  
 [261, 'Asia/Dubai', 'Asia/Dubai'],  
 [262, 'Asia/Dushanbe', 'Asia/Dushanbe'],  
 [263, 'Asia/Famagusta', 'Asia/Famagusta'],  
 [264, 'Asia/Gaza', 'Asia/Gaza'],  
 [265, 'Asia/Harbin', 'Asia/Harbin'],  
 [266, 'Asia/Hebron', 'Asia/Hebron'],  
 [267, 'Asia/Ho_Chi_Minh', 'Asia/Ho_Chi_Minh'],  
 [268, 'Asia/Hong_Kong', 'Asia/Hong_Kong'],  
 [269, 'Asia/Hovd', 'Asia/Hovd'],  
 [270, 'Asia/Irkutsk', 'Asia/Irkutsk'],  
 [271, 'Asia/Istanbul', 'Asia/Istanbul'],  
 [272, 'Asia/Jakarta', 'Asia/Jakarta'],  
 [273, 'Asia/Jayapura', 'Asia/Jayapura'],  
 [274, 'Asia/Jerusalem', 'Asia/Jerusalem'],  
 [275, 'Asia/Kabul', 'Asia/Kabul'],  
 [276, 'Asia/Kamchatka', 'Asia/Kamchatka'],  
 [277, 'Asia/Karachi', 'Asia/Karachi'],  
 [278, 'Asia/Kashgar', 'Asia/Kashgar'],  
 [279, 'Asia/Kathmandu', 'Asia/Kathmandu'],  
 [280, 'Asia/Katmandu', 'Asia/Katmandu'],  
 [281, 'Asia/Khandyga', 'Asia/Khandyga'],  
 [282, 'Asia/Kolkata', 'Asia/Kolkata'],  
 [283, 'Asia/Krasnoyarsk', 'Asia/Krasnoyarsk'],  
 [284, 'Asia/Kuala_Lumpur', 'Asia/Kuala_Lumpur'],  
 [285, 'Asia/Kuching', 'Asia/Kuching'],  
 [286, 'Asia/Kuwait', 'Asia/Kuwait'],  
 [287, 'Asia/Macao', 'Asia/Macao'],  
 [288, 'Asia/Macau', 'Asia/Macau'],  
 [289, 'Asia/Magadan', 'Asia/Magadan'],  
 [290, 'Asia/Makassar', 'Asia/Makassar'],  
 [291, 'Asia/Manila', 'Asia/Manila'],  
 [292, 'Asia/Muscat', 'Asia/Muscat'],  
 [293, 'Asia/Nicosia', 'Asia/Nicosia'],  
 [294, 'Asia/Novokuznetsk', 'Asia/Novokuznetsk'],  
 [295, 'Asia/Novosibirsk', 'Asia/Novosibirsk'],  
 [296, 'Asia/Omsk', 'Asia/Omsk'],  
 [297, 'Asia/Oral', 'Asia/Oral'],  
 [298, 'Asia/Phnom_Penh', 'Asia/Phnom_Penh'],  
 [299, 'Asia/Pontianak', 'Asia/Pontianak'],  
 [300, 'Asia/Pyongyang', 'Asia/Pyongyang'],  
 [301, 'Asia/Qatar', 'Asia/Qatar'],  
 [302, 'Asia/Qostanay', 'Asia/Qostanay'],  
 [303, 'Asia/Qyzylorda', 'Asia/Qyzylorda'],  
 [304, 'Asia/Rangoon', 'Asia/Rangoon'],  
 [305, 'Asia/Riyadh', 'Asia/Riyadh'],  
 [306, 'Asia/Saigon', 'Asia/Saigon'],  
 [307, 'Asia/Sakhalin', 'Asia/Sakhalin'],  
 [308, 'Asia/Samarkand', 'Asia/Samarkand'],  
 [309, 'Asia/Seoul', 'Asia/Seoul'],  
 [310, 'Asia/Shanghai', 'Asia/Shanghai'],  
 [311, 'Asia/Singapore', 'Asia/Singapore'],  
 [312, 'Asia/Srednekolymsk', 'Asia/Srednekolymsk'],  
 [313, 'Asia/Taipei', 'Asia/Taipei'],  
 [314, 'Asia/Tashkent', 'Asia/Tashkent'],  
 [315, 'Asia/Tbilisi', 'Asia/Tbilisi'],  
 [316, 'Asia/Tehran', 'Asia/Tehran'],  
 [317, 'Asia/Tel_Aviv', 'Asia/Tel_Aviv'],  
 [318, 'Asia/Thimbu', 'Asia/Thimbu'],  
 [319, 'Asia/Thimphu', 'Asia/Thimphu'],  
 [320, 'Asia/Tokyo', 'Asia/Tokyo'],  
 [321, 'Asia/Tomsk', 'Asia/Tomsk'],  
 [322, 'Asia/Ujung_Pandang', 'Asia/Ujung_Pandang'],  
 [323, 'Asia/Ulaanbaatar', 'Asia/Ulaanbaatar'],  
 [324, 'Asia/Ulan_Bator', 'Asia/Ulan_Bator'],  
 [325, 'Asia/Urumqi', 'Asia/Urumqi'],  
 [326, 'Asia/Ust-Nera', 'Asia/Ust-Nera'],  
 [327, 'Asia/Vientiane', 'Asia/Vientiane'],  
 [328, 'Asia/Vladivostok', 'Asia/Vladivostok'],  
 [329, 'Asia/Yakutsk', 'Asia/Yakutsk'],  
 [330, 'Asia/Yangon', 'Asia/Yangon'],  
 [331, 'Asia/Yekaterinburg', 'Asia/Yekaterinburg'],  
 [332, 'Asia/Yerevan', 'Asia/Yerevan'],  
 [333, 'Atlantic/Azores', 'Atlantic/Azores'],  
 [334, 'Atlantic/Bermuda', 'Atlantic/Bermuda'],  
 [335, 'Atlantic/Canary', 'Atlantic/Canary'],  
 [336, 'Atlantic/Cape_Verde', 'Atlantic/Cape_Verde'],  
 [337, 'Atlantic/Faeroe', 'Atlantic/Faeroe'],  
 [338, 'Atlantic/Faroe', 'Atlantic/Faroe'],  
 [339, 'Atlantic/Jan_Mayen', 'Atlantic/Jan_Mayen'],  
 [340, 'Atlantic/Madeira', 'Atlantic/Madeira'],  
 [341, 'Atlantic/Reykjavik', 'Atlantic/Reykjavik'],  
 [342, 'Atlantic/South_Georgia', 'Atlantic/South_Georgia'],  
 [343, 'Atlantic/St_Helena', 'Atlantic/St_Helena'],  
 [344, 'Atlantic/Stanley', 'Atlantic/Stanley'],  
 [345, 'Australia/ACT', 'Australia/ACT'],  
 [346, 'Australia/Adelaide', 'Australia/Adelaide'],  
 [347, 'Australia/Brisbane', 'Australia/Brisbane'],  
 [348, 'Australia/Broken_Hill', 'Australia/Broken_Hill'],  
 [349, 'Australia/Canberra', 'Australia/Canberra'],  
 [350, 'Australia/Currie', 'Australia/Currie'],  
 [351, 'Australia/Darwin', 'Australia/Darwin'],  
 [352, 'Australia/Eucla', 'Australia/Eucla'],  
 [353, 'Australia/Hobart', 'Australia/Hobart'],  
 [354, 'Australia/LHI', 'Australia/LHI'],  
 [355, 'Australia/Lindeman', 'Australia/Lindeman'],  
 [356, 'Australia/Lord_Howe', 'Australia/Lord_Howe'],  
 [357, 'Australia/Melbourne', 'Australia/Melbourne'],  
 [358, 'Australia/NSW', 'Australia/NSW'],  
 [359, 'Australia/North', 'Australia/North'],  
 [360, 'Australia/Perth', 'Australia/Perth'],  
 [361, 'Australia/Queensland', 'Australia/Queensland'],  
 [362, 'Australia/South', 'Australia/South'],  
 [363, 'Australia/Sydney', 'Australia/Sydney'],  
 [364, 'Australia/Tasmania', 'Australia/Tasmania'],  
 [365, 'Australia/Victoria', 'Australia/Victoria'],  
 [366, 'Australia/West', 'Australia/West'],  
 [367, 'Australia/Yancowinna', 'Australia/Yancowinna'],  
 [368, 'Brazil/Acre', 'Brazil/Acre'],  
 [369, 'Brazil/DeNoronha', 'Brazil/DeNoronha'],  
 [370, 'Brazil/East', 'Brazil/East'],  
 [371, 'Brazil/West', 'Brazil/West'],  
 [372, 'CET', 'CET'],  
 [373, 'CST6CDT', 'CST6CDT'],  
 [374, 'Canada/Atlantic', 'Canada/Atlantic'],  
 [375, 'Canada/Central', 'Canada/Central'],  
 [376, 'Canada/Eastern', 'Canada/Eastern'],  
 [377, 'Canada/Mountain', 'Canada/Mountain'],  
 [378, 'Canada/Newfoundland', 'Canada/Newfoundland'],  
 [379, 'Canada/Pacific', 'Canada/Pacific'],  
 [380, 'Canada/Saskatchewan', 'Canada/Saskatchewan'],  
 [381, 'Canada/Yukon', 'Canada/Yukon'],  
 [382, 'Chile/Continental', 'Chile/Continental'],  
 [383, 'Chile/EasterIsland', 'Chile/EasterIsland'],  
 [384, 'Cuba', 'Cuba'],  
 [385, 'EET', 'EET'],  
 [386, 'EST', 'EST'],  
 [387, 'EST5EDT', 'EST5EDT'],  
 [388, 'Egypt', 'Egypt'],  
 [389, 'Eire', 'Eire'],  
 [390, 'Etc/GMT', 'Etc/GMT'],  
 [391, 'Etc/GMT+0', 'Etc/GMT+0'],  
 [392, 'Etc/GMT+1', 'Etc/GMT+1'],  
 [393, 'Etc/GMT+10', 'Etc/GMT+10'],  
 [394, 'Etc/GMT+11', 'Etc/GMT+11'],  
 [395, 'Etc/GMT+12', 'Etc/GMT+12'],  
 [396, 'Etc/GMT+2', 'Etc/GMT+2'],  
 [397, 'Etc/GMT+3', 'Etc/GMT+3'],  
 [398, 'Etc/GMT+4', 'Etc/GMT+4'],  
 [399, 'Etc/GMT+5', 'Etc/GMT+5'],  
 [400, 'Etc/GMT+6', 'Etc/GMT+6'],  
 [401, 'Etc/GMT+7', 'Etc/GMT+7'],  
 [402, 'Etc/GMT+8', 'Etc/GMT+8'],  
 [403, 'Etc/GMT+9', 'Etc/GMT+9'],  
 [404, 'Etc/GMT-0', 'Etc/GMT-0'],  
 [405, 'Etc/GMT-1', 'Etc/GMT-1'],  
 [406, 'Etc/GMT-10', 'Etc/GMT-10'],  
 [407, 'Etc/GMT-11', 'Etc/GMT-11'],  
 [408, 'Etc/GMT-12', 'Etc/GMT-12'],  
 [409, 'Etc/GMT-13', 'Etc/GMT-13'],  
 [410, 'Etc/GMT-14', 'Etc/GMT-14'],  
 [411, 'Etc/GMT-2', 'Etc/GMT-2'],  
 [412, 'Etc/GMT-3', 'Etc/GMT-3'],  
 [413, 'Etc/GMT-4', 'Etc/GMT-4'],  
 [414, 'Etc/GMT-5', 'Etc/GMT-5'],  
 [415, 'Etc/GMT-6', 'Etc/GMT-6'],  
 [416, 'Etc/GMT-7', 'Etc/GMT-7'],  
 [417, 'Etc/GMT-8', 'Etc/GMT-8'],  
 [418, 'Etc/GMT-9', 'Etc/GMT-9'],  
 [419, 'Etc/GMT0', 'Etc/GMT0'],  
 [420, 'Etc/Greenwich', 'Etc/Greenwich'],  
 [421, 'Etc/UCT', 'Etc/UCT'],  
 [422, 'Etc/UTC', 'Etc/UTC'],  
 [423, 'Etc/Universal', 'Etc/Universal'],  
 [424, 'Etc/Zulu', 'Etc/Zulu'],  
 [425, 'Europe/Amsterdam', 'Europe/Amsterdam'],  
 [426, 'Europe/Andorra', 'Europe/Andorra'],  
 [427, 'Europe/Astrakhan', 'Europe/Astrakhan'],  
 [428, 'Europe/Athens', 'Europe/Athens'],  
 [429, 'Europe/Belfast', 'Europe/Belfast'],  
 [430, 'Europe/Belgrade', 'Europe/Belgrade'],  
 [431, 'Europe/Berlin', 'Europe/Berlin'],  
 [432, 'Europe/Bratislava', 'Europe/Bratislava'],  
 [433, 'Europe/Brussels', 'Europe/Brussels'],  
 [434, 'Europe/Bucharest', 'Europe/Bucharest'],  
 [435, 'Europe/Budapest', 'Europe/Budapest'],  
 [436, 'Europe/Busingen', 'Europe/Busingen'],  
 [437, 'Europe/Chisinau', 'Europe/Chisinau'],  
 [438, 'Europe/Copenhagen', 'Europe/Copenhagen'],  
 [439, 'Europe/Dublin', 'Europe/Dublin'],  
 [440, 'Europe/Gibraltar', 'Europe/Gibraltar'],  
 [441, 'Europe/Guernsey', 'Europe/Guernsey'],  
 [442, 'Europe/Helsinki', 'Europe/Helsinki'],  
 [443, 'Europe/Isle_of_Man', 'Europe/Isle_of_Man'],  
 [444, 'Europe/Istanbul', 'Europe/Istanbul'],  
 [445, 'Europe/Jersey', 'Europe/Jersey'],  
 [446, 'Europe/Kaliningrad', 'Europe/Kaliningrad'],  
 [447, 'Europe/Kiev', 'Europe/Kiev'],  
 [448, 'Europe/Kirov', 'Europe/Kirov'],  
 [449, 'Europe/Lisbon', 'Europe/Lisbon'],  
 [450, 'Europe/Ljubljana', 'Europe/Ljubljana'],  
 [451, 'Europe/London', 'Europe/London'],  
 [452, 'Europe/Luxembourg', 'Europe/Luxembourg'],  
 [453, 'Europe/Madrid', 'Europe/Madrid'],  
 [454, 'Europe/Malta', 'Europe/Malta'],  
 [455, 'Europe/Mariehamn', 'Europe/Mariehamn'],  
 [456, 'Europe/Minsk', 'Europe/Minsk'],  
 [457, 'Europe/Monaco', 'Europe/Monaco'],  
 [458, 'Europe/Moscow', 'Europe/Moscow'],  
 [459, 'Europe/Nicosia', 'Europe/Nicosia'],  
 [460, 'Europe/Oslo', 'Europe/Oslo'],  
 [461, 'Europe/Paris', 'Europe/Paris'],  
 [462, 'Europe/Podgorica', 'Europe/Podgorica'],  
 [463, 'Europe/Prague', 'Europe/Prague'],  
 [464, 'Europe/Riga', 'Europe/Riga'],  
 [465, 'Europe/Rome', 'Europe/Rome'],  
 [466, 'Europe/Samara', 'Europe/Samara'],  
 [467, 'Europe/San_Marino', 'Europe/San_Marino'],  
 [468, 'Europe/Sarajevo', 'Europe/Sarajevo'],  
 [469, 'Europe/Saratov', 'Europe/Saratov'],  
 [470, 'Europe/Simferopol', 'Europe/Simferopol'],  
 [471, 'Europe/Skopje', 'Europe/Skopje'],  
 [472, 'Europe/Sofia', 'Europe/Sofia'],  
 [473, 'Europe/Stockholm', 'Europe/Stockholm'],  
 [474, 'Europe/Tallinn', 'Europe/Tallinn'],  
 [475, 'Europe/Tirane', 'Europe/Tirane'],  
 [476, 'Europe/Tiraspol', 'Europe/Tiraspol'],  
 [477, 'Europe/Ulyanovsk', 'Europe/Ulyanovsk'],  
 [478, 'Europe/Uzhgorod', 'Europe/Uzhgorod'],  
 [479, 'Europe/Vaduz', 'Europe/Vaduz'],  
 [480, 'Europe/Vatican', 'Europe/Vatican'],  
 [481, 'Europe/Vienna', 'Europe/Vienna'],  
 [482, 'Europe/Vilnius', 'Europe/Vilnius'],  
 [483, 'Europe/Volgograd', 'Europe/Volgograd'],  
 [484, 'Europe/Warsaw', 'Europe/Warsaw'],  
 [485, 'Europe/Zagreb', 'Europe/Zagreb'],  
 [486, 'Europe/Zaporozhye', 'Europe/Zaporozhye'],  
 [487, 'Europe/Zurich', 'Europe/Zurich'],  
 [488, 'GB', 'GB'],  
 [489, 'GB-Eire', 'GB-Eire'],  
 [490, 'GMT', 'GMT'],  
 [491, 'GMT+0', 'GMT+0'],  
 [492, 'GMT-0', 'GMT-0'],  
 [493, 'GMT0', 'GMT0'],  
 [494, 'Greenwich', 'Greenwich'],  
 [495, 'HST', 'HST'],  
 [496, 'Hongkong', 'Hongkong'],  
 [497, 'Iceland', 'Iceland'],  
 [498, 'Indian/Antananarivo', 'Indian/Antananarivo'],  
 [499, 'Indian/Chagos', 'Indian/Chagos'],  
 [500, 'Indian/Christmas', 'Indian/Christmas'],  
 [501, 'Indian/Cocos', 'Indian/Cocos'],  
 [502, 'Indian/Comoro', 'Indian/Comoro'],  
 [503, 'Indian/Kerguelen', 'Indian/Kerguelen'],  
 [504, 'Indian/Mahe', 'Indian/Mahe'],  
 [505, 'Indian/Maldives', 'Indian/Maldives'],  
 [506, 'Indian/Mauritius', 'Indian/Mauritius'],  
 [507, 'Indian/Mayotte', 'Indian/Mayotte'],  
 [508, 'Indian/Reunion', 'Indian/Reunion'],  
 [509, 'Iran', 'Iran'],  
 [510, 'Israel', 'Israel'],  
 [511, 'Jamaica', 'Jamaica'],  
 [512, 'Japan', 'Japan'],  
 [513, 'Kwajalein', 'Kwajalein'],  
 [514, 'Libya', 'Libya'],  
 [515, 'MET', 'MET'],  
 [516, 'MST', 'MST'],  
 [517, 'MST7MDT', 'MST7MDT'],  
 [518, 'Mexico/BajaNorte', 'Mexico/BajaNorte'],  
 [519, 'Mexico/BajaSur', 'Mexico/BajaSur'],  
 [520, 'Mexico/General', 'Mexico/General'],  
 [521, 'NZ', 'NZ'],  
 [522, 'NZ-CHAT', 'NZ-CHAT'],  
 [523, 'Navajo', 'Navajo'],  
 [524, 'PRC', 'PRC'],  
 [525, 'PST8PDT', 'PST8PDT'],  
 [526, 'Pacific/Apia', 'Pacific/Apia'],  
 [527, 'Pacific/Auckland', 'Pacific/Auckland'],  
 [528, 'Pacific/Bougainville', 'Pacific/Bougainville'],  
 [529, 'Pacific/Chatham', 'Pacific/Chatham'],  
 [530, 'Pacific/Chuuk', 'Pacific/Chuuk'],  
 [531, 'Pacific/Easter', 'Pacific/Easter'],  
 [532, 'Pacific/Efate', 'Pacific/Efate'],  
 [533, 'Pacific/Enderbury', 'Pacific/Enderbury'],  
 [534, 'Pacific/Fakaofo', 'Pacific/Fakaofo'],  
 [535, 'Pacific/Fiji', 'Pacific/Fiji'],  
 [536, 'Pacific/Funafuti', 'Pacific/Funafuti'],  
 [537, 'Pacific/Galapagos', 'Pacific/Galapagos'],  
 [538, 'Pacific/Gambier', 'Pacific/Gambier'],  
 [539, 'Pacific/Guadalcanal', 'Pacific/Guadalcanal'],  
 [540, 'Pacific/Guam', 'Pacific/Guam'],  
 [541, 'Pacific/Honolulu', 'Pacific/Honolulu'],  
 [542, 'Pacific/Johnston', 'Pacific/Johnston'],  
 [543, 'Pacific/Kiritimati', 'Pacific/Kiritimati'],  
 [544, 'Pacific/Kosrae', 'Pacific/Kosrae'],  
 [545, 'Pacific/Kwajalein', 'Pacific/Kwajalein'],  
 [546, 'Pacific/Majuro', 'Pacific/Majuro'],  
 [547, 'Pacific/Marquesas', 'Pacific/Marquesas'],  
 [548, 'Pacific/Midway', 'Pacific/Midway'],  
 [549, 'Pacific/Nauru', 'Pacific/Nauru'],  
 [550, 'Pacific/Niue', 'Pacific/Niue'],  
 [551, 'Pacific/Norfolk', 'Pacific/Norfolk'],  
 [552, 'Pacific/Noumea', 'Pacific/Noumea'],  
 [553, 'Pacific/Pago_Pago', 'Pacific/Pago_Pago'],  
 [554, 'Pacific/Palau', 'Pacific/Palau'],  
 [555, 'Pacific/Pitcairn', 'Pacific/Pitcairn'],  
 [556, 'Pacific/Pohnpei', 'Pacific/Pohnpei'],  
 [557, 'Pacific/Ponape', 'Pacific/Ponape'],  
 [558, 'Pacific/Port_Moresby', 'Pacific/Port_Moresby'],  
 [559, 'Pacific/Rarotonga', 'Pacific/Rarotonga'],  
 [560, 'Pacific/Saipan', 'Pacific/Saipan'],  
 [561, 'Pacific/Samoa', 'Pacific/Samoa'],  
 [562, 'Pacific/Tahiti', 'Pacific/Tahiti'],  
 [563, 'Pacific/Tarawa', 'Pacific/Tarawa'],  
 [564, 'Pacific/Tongatapu', 'Pacific/Tongatapu'],  
 [565, 'Pacific/Truk', 'Pacific/Truk'],  
 [566, 'Pacific/Wake', 'Pacific/Wake'],  
 [567, 'Pacific/Wallis', 'Pacific/Wallis'],  
 [568, 'Pacific/Yap', 'Pacific/Yap'],  
 [569, 'Poland', 'Poland'],  
 [570, 'Portugal', 'Portugal'],  
 [571, 'ROC', 'ROC'],  
 [572, 'ROK', 'ROK'],  
 [573, 'Singapore', 'Singapore'],  
 [574, 'Turkey', 'Turkey'],  
 [575, 'UCT', 'UCT'],  
 [576, 'US/Alaska', 'US/Alaska'],  
 [577, 'US/Aleutian', 'US/Aleutian'],  
 [578, 'US/Arizona', 'US/Arizona'],  
 [579, 'US/Central', 'US/Central'],  
 [580, 'US/East-Indiana', 'US/East-Indiana'],  
 [581, 'US/Eastern', 'US/Eastern'],  
 [582, 'US/Hawaii', 'US/Hawaii'],  
 [583, 'US/Indiana-Starke', 'US/Indiana-Starke'],  
 [584, 'US/Michigan', 'US/Michigan'],  
 [585, 'US/Mountain', 'US/Mountain'],  
 [586, 'US/Pacific', 'US/Pacific'],  
 [587, 'US/Samoa', 'US/Samoa'],  
 [588, 'UTC', 'UTC'],  
 [589, 'Universal', 'Universal'],  
 [590, 'W-SU', 'W-SU'],  
 [591, 'WET', 'WET'],  
 [592, 'Zulu', 'Zulu']]
#### Station Types ####
  * Station Types: [  
 [0, 'Unknown', 'unknown'],  
 [1, 'Background', 'background'],  
 [2, 'Traffic', 'traffic'],  
 [3, 'Industrial', 'industrial'],  
 [4, 'Other', 'other']]
#### Station Type Of Area ####
  * Station Type of Area: [  
 [0, 'Unknown', 'unknown'],  
 [1, 'Urban', 'urban'],  
 [2, 'Suburban', 'suburban'],  
 [3, 'Rural', 'rural'],  
 [4, 'Remote', 'remote']]
#### Station Toar Categories ####
  * Station TOAR Categories: [  
 [-1, 'Unknown', 'unknown'],  
 [0, 'Unclassified', 'unclassified'],  
 [1, 'RuralLowElevation', 'rural low elevation'],  
 [2, 'RuralHighElevation', 'rural high elevation'],  
 [3, 'Urban', 'urban']]
#### Station Htap Regions ####
  * Station HTAP Regions: [  
 [-1, 'HTAPTier1Undefined', '-1 (undefined)'],  
 [1, 'HTAPTier1World', '1 (World)'],  
 [2, 'HTAPTier1OCN', '2 (OCN Non-arctic/Antarctic Ocean)'],  
 [3, 'HTAPTier1NAM', '3 (NAM US+Canada (upto 66 N; polar circle))'],  
 [4, 'HTAPTier1EUR', '4 (EUR Western + Eastern EU+Turkey (upto 66 N polar circle))'],  
 [5, 'HTAPTier1SAS', '5 (SAS South Asia: India, Nepal, Pakistan, Afghanistan, Bangadesh, Sri Lanka)'],  
 [6, 'HTAPTier1EAS', '6 (EAS East Asia: China, Korea, Japan)'],  
 [7, 'HTAPTier1SEA', '7 (SEA South East Asia)'],  
 [8, 'HTAPTier1PAN', '8 (PAN Pacific, Australia+ New Zealand)'],  
 [9, 'HTAPTier1NAF', '9 (NAF Northern Africa+Sahara+Sahel)'],  
 [10, 'HTAPTier1SAF', '10 (SAF Sub Saharan/sub Sahel Africa)'],  
 [11, 'HTAPTier1MDE', '11 (MDE Middle East: S. Arabia, Oman, etc, Iran, Iraq)'],  
 [12, 'HTAPTier1MCA', '12 (MCA Mexico, Central America, Caribbean, Guyanas, Venezuela, Columbia)'],  
 [13, 'HTAPTier1SAM', '13 (SAM S. America)'],  
 [14, 'HTAPTier1RBU', '14 (RBU Russia, Belarussia, Ukraine)'],  
 [15, 'HTAPTier1CAS', '15 (CAS Central Asia)'],  
 [16, 'HTAPTier1NPO', '16 (NPO Arctic Circle (North of 66 N) + Greenland)'],  
 [17, 'HTAPTier1SPO', '17 (SPO Antarctic)']]
#### Station Dominant Landcover Types ####
  * Station Dominant Landcover Types: [  
 [-1, 'Undefined', '-1 (undefined)'],  
 [0, 'Water', '0 (Water)'],  
 [1, 'EGNeedleleaf', '1  (Evergreen Needleleaf forest)'],  
 [2, 'EGBroadleaf', '2  (Evergreen Broadleaf forest)'],  
 [3, 'DCNeedleleaf', '3  (Deciduous Needleleaf forest)'],  
 [4, 'DCBroadleaf', '4  (Deciduous Broadleaf forest)'],  
 [5, 'MixedForest', '5  (Mixed forest)'],  
 [6, 'ClosedShrublands', '6  (Closed shrublands)'],  
 [7, 'OpenShrublands', '7  (Open shrublands)'],  
 [8, 'WoodySavannas', '8  (Woody savannas)'],  
 [9, 'Savannas', '9  (Savannas)'],  
 [10, 'Grasslands', '10  (Grasslands)'],  
 [11, 'Wetlands', '11  (Permanent wetlands)'],  
 [12, 'Croplands', '12  (Croplands)'],  
 [13, 'Urban', '13  (Urban and built-up)'],  
 [14, 'Mosaic', '14  (Cropland/Natural vegetation mosaic)'],  
 [15, 'Snow', '15  (Snow and ice)'],  
 [16, 'Barren', '16  (Barren or sparsely vegetated)'],  
 [255, 'Fill', '255 (Fill Value/Unclassified)']]
#### Result Types ####
  * Result Types: [  
 [0, 'String', 'str'],  
 [1, 'Integer', 'int'],  
 [2, 'Float', 'float']]
#### Data Flags ####
  * Data Flags: [  
 [0, 'OK', 'OK'],  
 [1, 'OKPreliminary', 'OK preliminary'],  
 [2, 'OKModified', 'OK modified'],  
 [3, 'OKPreliminaryModified', 'OK preliminary modified'],  
 [4, 'Inconsistent', 'inconsistent'],  
 [5, 'InconsistentPreliminary', 'inconsistent preliminary'],  
 [6, 'Doubtful', 'doubtful'],  
 [7, 'DoubtfulPreliminary', 'doubtful preliminary'],  
 [8, 'DoubtfulModified', 'doubtful modified'],  
 [9, 'DoubtfulPreliminaryModified', 'doubtful preliminary modified'],  
 [10, 'Wrong', 'wrong'],  
 [11, 'WrongPreliminary', 'wrong preliminary'],  
 [12, 'NotCheckedPreliminary', 'not checked preliminary'],  
 [13, 'Changed', 'changed'],  
 [14, 'Estimated', 'estimated'],  
 [15, 'MissingValue', 'missing value']]
#### Type Of Change ####
  * Type of Change: [  
 [0, 'Created', 'created'],  
 [1, 'SingleValue', 'single value correction in metadata'],  
 [2, 'Comprehensive', 'comprehensive metadata revision'],  
 [3, 'Typo', 'typographic correction of metadata'],  
 [4, 'UnspecifiedData', 'unspecified data value corrections'],  
 [5, 'Replaced', 'replaced data with a new version'],  
 [6, 'Flagging', 'data value flagging']]


## REST API

### /controlled_vocabulary/

#### GET
##### Summary:

Info

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |

### /controlled_vocabulary/{name}

#### GET
##### Summary:

Info

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /database_statistics/

#### GET
##### Summary:

Info

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |

### /database_statistics/{name}

#### GET
##### Summary:

Info

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /variables/

#### GET
##### Summary:

Get Variables

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /variables/{name}

#### GET
##### Summary:

Get Variable

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /variables/id/{variable_id}

#### GET
##### Summary:

Get Variable

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| variable_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/

#### GET
##### Summary:

Get All Persons

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/id/{person_id}

#### GET
##### Summary:

Get Person

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| person_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/{name}

#### GET
##### Summary:

Get Person

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/

#### GET
##### Summary:

Get All Organisations

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/id/{organisation_id}

#### GET
##### Summary:

Get Organisation

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| organisation_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/{name}

#### GET
##### Summary:

Get Organisation

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/

#### GET
##### Summary:

Get All Contacts

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/id/{contact_id}

#### GET
##### Summary:

Get All Contacts

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| contact_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/orga_name/{name}

#### GET
##### Summary:

Get All Contacts

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta_core/

#### GET
##### Summary:

Get All Stationmeta Core

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/

#### GET
##### Summary:

Get All Stationmeta

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta_core/{station_code}

#### GET
##### Summary:

Get Stationmeta Core

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_code | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/{station_code}

#### GET
##### Summary:

Get Stationmeta

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_code | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/id/{station_id}

#### GET
##### Summary:

Get Stationmeta By Id

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta_changelog/{station_id}

#### GET
##### Summary:

Get Stationmeta Changelog

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/delete_field/{station_code}

### /timeseries/

#### GET
##### Summary:

Get All Timeseries

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/{timeseries_id}

#### GET
##### Summary:

Get Timeseries

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/id/{timeseries_id}

#### GET
##### Summary:

Get Timeseries2

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/unique/

#### GET
##### Summary:

Get Timeseries

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_id | query |  | Yes | integer |
| variable_id | query |  | Yes | integer |
| resource_provider | query |  | Yes | string |
| label | query |  | No | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries_changelog/{timeseries_id}

#### GET
##### Summary:

Get Timeseries Changelog

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/delete_field/{timeseries_id}

### /data/

#### GET
##### Summary:

Get All Data

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /data/{timeseries_id}

#### GET
##### Summary:

Get Data

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |
| format | query |  | No | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /data/id/{timeseries_id}

#### GET
##### Summary:

Get Data2

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |
| format | query |  | No | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /data/record/

