from sqlalchemy import Table, Column, Integer, String
from sqlalchemy.ext.declarative import declarative_base
from .models_core import StationmetaCore
from .models_global import StationmetaGlobal
from .models_global_services import StationmetaGlobalService
from .models_role import StationmetaRole, stationmeta_core_stationmeta_roles_table
from .models_annotation import StationmetaAnnotation, stationmeta_core_stationmeta_annotations_table
from .models_aux import StationmetaAuxDoc, StationmetaAuxImage, StationmetaAuxUrl
from .models_changelog import StationmetaChangelog

from toardb.base import Base

# controlled vocabulary

# Station Climatic Zone
CZ_enum_table = Table("cz_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)


# After loosing one day without solution, the following workaround is introduced!
from collections import namedtuple
Enumdict=namedtuple("Dict",["value","string","display_str"])
#def __get_enum_dict(table: Table, db: Session = Depends(get_db)):
# This is not working (whereever I put it!) -- I have to investigate, how to do testing
# (and using tables in my testing environment!)"
# AND (EVEN MORE IMPORTANT):
# How to load enum_dicts once?!
# This is important to be able to use the enum_dicts within the validator of the pydantic model
# The following code is just a workaround:
CZ_enum = (
    Enumdict(-1, 'Undefined', 'undefined'),
    Enumdict( 0, 'Unclassified', 'unclassified'),
    Enumdict( 1, 'WarmTemperateMoist', 'warm temperate moist'),
    Enumdict( 2, 'WarmTemperateDry', 'warm temperate dry'),
    Enumdict( 3, 'CoolTemperateMoist', 'cool temperate moist'),
    Enumdict( 4, 'CoolTemperateDry', 'cool temperate dry'),
    Enumdict( 5, 'PolarMoist', 'polar moist'),
    Enumdict( 6, 'PolarDry', 'polar dry'),
    Enumdict( 7, 'BorealMoist', 'boreal moist'),
    Enumdict( 8, 'BorealDry', 'boreal dry'),
    Enumdict( 9, 'TropicalMontane', 'tropical montane'),
    Enumdict(10, 'TropicalWet', 'tropical wet'),
    Enumdict(11, 'TropicalMoist', 'tropical moist'),
    Enumdict(12, 'TropicalDry', 'tropical dry')
    )


# Station Coordinate Validity
CV_enum_table = Table("cv_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
CV_enum = (
    Enumdict(0, 'NotChecked', 'not checked'),
    Enumdict(1, 'Verified', 'verified'),
    Enumdict(2, 'Plausible', 'plausible'),
    Enumdict(3, 'Doubtful', 'doubtful'),
    Enumdict(4, 'Unverifyable', 'not verifyable')
    )

# Station Types 
ST_enum_table = Table("st_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
ST_enum = (
    Enumdict(0, 'Unknown', 'unknown'),
    Enumdict(1, 'Background', 'background'),
    Enumdict(2, 'Traffic', 'traffic'),
    Enumdict(3, 'Industrial', 'industrial'),
    Enumdict(4, 'Other', 'other')
    )

# Station Types of Area
TA_enum_table = Table("ta_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
TA_enum = (
    Enumdict(0, 'Unknown', 'unknown'),
    Enumdict(1, 'Urban', 'urban'),
    Enumdict(2, 'Suburban', 'suburban'),
    Enumdict(3, 'Rural', 'rural'),
    Enumdict(4, 'Remote', 'remote')
    )

# Station TOAR Categories
TC_enum_table = Table("tc_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
TC_enum = (
    Enumdict(-1, 'Unknown', 'unknown'),
    Enumdict( 0, 'Unclassified', 'unclassified'),
    Enumdict( 1, 'RuralLowElevation', 'rural low elevation'),
    Enumdict( 2, 'RuralHighElevation', 'rural high elevation'),
    Enumdict( 3, 'Urban', 'urban')
    )

# Station HTAP Regions (TIER1)
TR_enum_table = Table("tr_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
TR_enum = (
    Enumdict(-1, 'HTAPTier1Undefined', '-1 (undefined)'),
    Enumdict( 1, 'HTAPTier1World', '1 (World)'),
    Enumdict( 2, 'HTAPTier1OCN', '2 (OCN Non-arctic/Antarctic Ocean)'),
    Enumdict( 3, 'HTAPTier1NAM', '3 (NAM US+Canada (upto 66 N; polar circle))'),
    Enumdict( 4, 'HTAPTier1EUR', '4 (EUR Western + Eastern EU+Turkey (upto 66 N polar circle))'),
    Enumdict( 5, 'HTAPTier1SAS', '5 (SAS South Asia: India, Nepal, Pakistan, Afghanistan, Bangadesh, Sri Lanka)'),
    Enumdict( 6, 'HTAPTier1EAS', '6 (EAS East Asia: China, Korea, Japan)'),
    Enumdict( 7, 'HTAPTier1SEA', '7 (SEA South East Asia)'),
    Enumdict( 8, 'HTAPTier1PAN', '8 (PAN Pacific, Australia+ New Zealand)'),
    Enumdict( 9, 'HTAPTier1NAF', '9 (NAF Northern Africa+Sahara+Sahel)'),
    Enumdict(10, 'HTAPTier1SAF', '10 (SAF Sub Saharan/sub Sahel Africa)'),
    Enumdict(11, 'HTAPTier1MDE', '11 (MDE Middle East: S. Arabia, Oman, etc, Iran, Iraq)'),
    Enumdict(12, 'HTAPTier1MCA', '12 (MCA Mexico, Central America, Caribbean, Guyanas, Venezuela, Columbia)'),
    Enumdict(13, 'HTAPTier1SAM', '13 (SAM S. America)'),
    Enumdict(14, 'HTAPTier1RBU', '14 (RBU Russia, Belarussia, Ukraine)'),
    Enumdict(15, 'HTAPTier1CAS', '15 (CAS Central Asia)'),
    Enumdict(16, 'HTAPTier1NPO', '16 (NPO Arctic Circle (North of 66 N) + Greenland)'),
    Enumdict(17, 'HTAPTier1SPO', '17 (SPO Antarctic)')
    )

# Station Dominant Landcover Types
DL_enum_table = Table("dl_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
DL_enum = (
    Enumdict( -1, 'Undefined', '-1 (undefined)'),
    Enumdict(  0, 'Water', '0 (Water)'),
    Enumdict(  1, 'EGNeedleleaf', '1  (Evergreen Needleleaf forest)'),
    Enumdict(  2, 'EGBroadleaf', '2  (Evergreen Broadleaf forest)'),
    Enumdict(  3, 'DCNeedleleaf', '3  (Deciduous Needleleaf forest)'),
    Enumdict(  4, 'DCBroadleaf', '4  (Deciduous Broadleaf forest)'),
    Enumdict(  5, 'MixedForest', '5  (Mixed forest)'),
    Enumdict(  6, 'ClosedShrublands', '6  (Closed shrublands)'),
    Enumdict(  7, 'OpenShrublands', '7  (Open shrublands)'),
    Enumdict(  8, 'WoodySavannas', '8  (Woody savannas)'),
    Enumdict(  9, 'Savannas', '9  (Savannas)'),
    Enumdict( 10, 'Grasslands', '10  (Grasslands)'),
    Enumdict( 11, 'Wetlands', '11  (Permanent wetlands)'),
    Enumdict( 12, 'Croplands', '12  (Croplands)'),
    Enumdict( 13, 'Urban', '13  (Urban and built-up)'),
    Enumdict( 14, 'Mosaic', '14  (Cropland/Natural vegetation mosaic)'),
    Enumdict( 15, 'Snow', '15  (Snow and ice)'),
    Enumdict( 16, 'Barren', '16  (Barren or sparsely vegetated)'),
    Enumdict(255, 'Fill', '255 (Fill Value/Unclassified)')
    )

# Result Types
RT_enum_table = Table("rt_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
RT_enum = (
    Enumdict(0, 'String', 'str'),
    Enumdict(1, 'Integer', 'int'),
    Enumdict(2, 'Float', 'float')
    )

# Country names 
CN_enum_table = Table("cn_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
CN_enum = (
    Enumdict(-1, 'N/A', 'N/A'),
    Enumdict(0, 'AF', 'Afghanistan'),
    Enumdict(1, 'AX', 'Åland Islands'),
    Enumdict(2, 'AL', 'Albania'),
    Enumdict(3, 'DZ', 'Algeria'),
    Enumdict(4, 'AS', 'American Samoa'),
    Enumdict(5, 'AD', 'Andorra'),
    Enumdict(6, 'AO', 'Angola'),
    Enumdict(7, 'AI', 'Anguilla'),
    Enumdict(8, 'AQ', 'Antarctica'),
    Enumdict(9, 'AG', 'Antigua and Barbuda'),
    Enumdict(10, 'AR', 'Argentina'),
    Enumdict(11, 'AM', 'Armenia'),
    Enumdict(12, 'AW', 'Aruba'),
    Enumdict(13, 'AU', 'Australia'),
    Enumdict(14, 'AT', 'Austria'),
    Enumdict(15, 'AZ', 'Azerbaijan'),
    Enumdict(16, 'BS', 'Bahamas'),
    Enumdict(17, 'BH', 'Bahrain'),
    Enumdict(18, 'BD', 'Bangladesh'),
    Enumdict(19, 'BB', 'Barbados'),
    Enumdict(20, 'BY', 'Belarus'),
    Enumdict(21, 'BE', 'Belgium'),
    Enumdict(22, 'BZ', 'Belize'),
    Enumdict(23, 'BJ', 'Benin'),
    Enumdict(24, 'BM', 'Bermuda'),
    Enumdict(25, 'BT', 'Bhutan'),
    Enumdict(26, 'BO', 'Plurinational State of Bolivia'),
    Enumdict(27, 'BQ', 'Bonaire, Sint Eustatius and Saba'),
    Enumdict(28, 'BA', 'Bosnia and Herzegovina'),
    Enumdict(29, 'BW', 'Botswana'),
    Enumdict(30, 'BV', 'Bouvet Island'),
    Enumdict(31, 'BR', 'Brazil'),
    Enumdict(32, 'IO', 'British Indian Ocean Territory'),
    Enumdict(33, 'UM', 'United States Minor Outlying Islands'),
    Enumdict(34, 'VG', 'British Virgin Islands'),
    Enumdict(35, 'VI', 'U.S. Virgin Islands'),
    Enumdict(36, 'BN', 'Brunei Darussalam'),
    Enumdict(37, 'BG', 'Bulgaria'),
    Enumdict(38, 'BF', 'Burkina Faso'),
    Enumdict(39, 'BI', 'Burundi'),
    Enumdict(40, 'KH', 'Cambodia'),
    Enumdict(41, 'CM', 'Cameroon'),
    Enumdict(42, 'CA', 'Canada'),
    Enumdict(43, 'CV', 'Cabo Verde'),
    Enumdict(44, 'KY', 'Cayman Islands'),
    Enumdict(45, 'CF', 'Central African Republic'),
    Enumdict(46, 'TD', 'Chad'),
    Enumdict(47, 'CL', 'Chile'),
    Enumdict(48, 'CN', 'China'),
    Enumdict(49, 'CX', 'Christmas Island'),
    Enumdict(50, 'CC', 'Cocos (Keeling) Islands'),
    Enumdict(51, 'CO', 'Colombia'),
    Enumdict(52, 'KM', 'Comoros'),
    Enumdict(53, 'CG', 'Congo'),
    Enumdict(54, 'CD', 'Democratic Republic of the Congo'),
    Enumdict(55, 'CK', 'Cook Islands'),
    Enumdict(56, 'CR', 'Costa Rica'),
    Enumdict(57, 'HR', 'Croatia'),
    Enumdict(58, 'CU', 'Cuba'),
    Enumdict(59, 'CW', 'Curaçao'),
    Enumdict(60, 'CY', 'Cyprus'),
    Enumdict(61, 'CZ', 'Czech Republic'),
    Enumdict(62, 'DK', 'Denmark'),
    Enumdict(63, 'DJ', 'Djibouti'),
    Enumdict(64, 'DM', 'Dominica'),
    Enumdict(65, 'DO', 'Dominican Republic'),
    Enumdict(66, 'EC', 'Ecuador'),
    Enumdict(67, 'EG', 'Egypt'),
    Enumdict(68, 'SV', 'El Salvador'),
    Enumdict(69, 'GQ', 'Equatorial Guinea'),
    Enumdict(70, 'ER', 'Eritrea'),
    Enumdict(71, 'EE', 'Estonia'),
    Enumdict(72, 'ET', 'Ethiopia'),
    Enumdict(73, 'FK', 'Falkland Islands (Malvinas)'),
    Enumdict(74, 'FO', 'Faroe Islands'),
    Enumdict(75, 'FJ', 'Fiji'),
    Enumdict(76, 'FI', 'Finland'),
    Enumdict(77, 'FR', 'France'),
    Enumdict(78, 'GF', 'French Guiana'),
    Enumdict(79, 'PF', 'French Polynesia'),
    Enumdict(80, 'TF', 'French Southern Territories'),
    Enumdict(81, 'GA', 'Gabon'),
    Enumdict(82, 'GM', 'Gambia'),
    Enumdict(83, 'GE', 'Georgia'),
    Enumdict(84, 'DE', 'Germany'),
    Enumdict(85, 'GH', 'Ghana'),
    Enumdict(86, 'GI', 'Gibraltar'),
    Enumdict(87, 'GR', 'Greece'),
    Enumdict(88, 'GL', 'Greenland'),
    Enumdict(89, 'GD', 'Grenada'),
    Enumdict(90, 'GP', 'Guadeloupe'),
    Enumdict(91, 'GU', 'Guam'),
    Enumdict(92, 'GT', 'Guatemala'),
    Enumdict(93, 'GG', 'Guernsey'),
    Enumdict(94, 'GN', 'Guinea'),
    Enumdict(95, 'GW', 'Guinea-Bissau'),
    Enumdict(96, 'GY', 'Guyana'),
    Enumdict(97, 'HT', 'Haiti'),
    Enumdict(98, 'HM', 'Heard Island and McDonald Islands'),
    Enumdict(99, 'VA', 'Holy See'),
    Enumdict(100, 'HN', 'Honduras'),
    Enumdict(101, 'HK', 'Hong Kong'),
    Enumdict(102, 'HU', 'Hungary'),
    Enumdict(103, 'IS', 'Iceland'),
    Enumdict(104, 'IN', 'India'),
    Enumdict(105, 'ID', 'Indonesia'),
    Enumdict(106, 'CI', 'Côte d''Ivoire'),
    Enumdict(107, 'IR', 'Islamic Republic of Iran'),
    Enumdict(108, 'IQ', 'Iraq'),
    Enumdict(109, 'IE', 'Ireland'),
    Enumdict(110, 'IM', 'Isle of Man'),
    Enumdict(111, 'IL', 'Israel'),
    Enumdict(112, 'IT', 'Italy'),
    Enumdict(113, 'JM', 'Jamaica'),
    Enumdict(114, 'JP', 'Japan'),
    Enumdict(115, 'JE', 'Jersey'),
    Enumdict(116, 'JO', 'Jordan'),
    Enumdict(117, 'KZ', 'Kazakhstan'),
    Enumdict(118, 'KE', 'Kenya'),
    Enumdict(119, 'KI', 'Kiribati'),
    Enumdict(120, 'KW', 'Kuwait'),
    Enumdict(121, 'KG', 'Kyrgyzstan'),
    Enumdict(122, 'LA', 'Lao People''s Democratic Republic'),
    Enumdict(123, 'LV', 'Latvia'),
    Enumdict(124, 'LB', 'Lebanon'),
    Enumdict(125, 'LS', 'Lesotho'),
    Enumdict(126, 'LR', 'Liberia'),
    Enumdict(127, 'LY', 'Libya'),
    Enumdict(128, 'LI', 'Liechtenstein'),
    Enumdict(129, 'LT', 'Lithuania'),
    Enumdict(130, 'LU', 'Luxembourg'),
    Enumdict(131, 'MO', 'Macao'),
    Enumdict(132, 'MK', 'North Macedonia'),
    Enumdict(133, 'MG', 'Madagascar'),
    Enumdict(134, 'MW', 'Malawi'),
    Enumdict(135, 'MY', 'Malaysia'),
    Enumdict(136, 'MV', 'Maldives'),
    Enumdict(137, 'ML', 'Mali'),
    Enumdict(138, 'MT', 'Malta'),
    Enumdict(139, 'MH', 'Marshall Islands'),
    Enumdict(140, 'MQ', 'Martinique'),
    Enumdict(141, 'MR', 'Mauritania'),
    Enumdict(142, 'MU', 'Mauritius'),
    Enumdict(143, 'YT', 'Mayotte'),
    Enumdict(144, 'MX', 'Mexico'),
    Enumdict(145, 'FM', 'Federated States of Micronesia'),
    Enumdict(146, 'MD', 'Republic of Moldova'),
    Enumdict(147, 'MC', 'Monaco'),
    Enumdict(148, 'MN', 'Mongolia'),
    Enumdict(149, 'ME', 'Montenegro'),
    Enumdict(150, 'MS', 'Montserrat'),
    Enumdict(151, 'MA', 'Morocco'),
    Enumdict(152, 'MZ', 'Mozambique'),
    Enumdict(153, 'MM', 'Myanmar'),
    Enumdict(154, 'NA', 'Namibia'),
    Enumdict(155, 'NR', 'Nauru'),
    Enumdict(156, 'NP', 'Nepal'),
    Enumdict(157, 'NL', 'Netherlands'),
    Enumdict(158, 'NC', 'New Caledonia'),
    Enumdict(159, 'NZ', 'New Zealand'),
    Enumdict(160, 'NI', 'Nicaragua'),
    Enumdict(161, 'NE', 'Niger'),
    Enumdict(162, 'NG', 'Nigeria'),
    Enumdict(163, 'NU', 'Niue'),
    Enumdict(164, 'NF', 'Norfolk Island'),
    Enumdict(165, 'KP', 'Democratic People''s Republic of Korea'),
    Enumdict(166, 'MP', 'Northern Mariana Islands'),
    Enumdict(167, 'NO', 'Norway'),
    Enumdict(168, 'OM', 'Oman'),
    Enumdict(169, 'PK', 'Pakistan'),
    Enumdict(170, 'PW', 'Palau'),
    Enumdict(171, 'PS', 'State of Palestine'),
    Enumdict(172, 'PA', 'Panama'),
    Enumdict(173, 'PG', 'Papua New Guinea'),
    Enumdict(174, 'PY', 'Paraguay'),
    Enumdict(175, 'PE', 'Peru'),
    Enumdict(176, 'PH', 'Philippines'),
    Enumdict(177, 'PN', 'Pitcairn'),
    Enumdict(178, 'PL', 'Poland'),
    Enumdict(179, 'PT', 'Portugal'),
    Enumdict(180, 'PR', 'Puerto Rico'),
    Enumdict(181, 'QA', 'Qatar'),
    Enumdict(182, 'XK', 'Republic of Kosovo'),
    Enumdict(183, 'RE', 'Réunion'),
    Enumdict(184, 'RO', 'Romania'),
    Enumdict(185, 'RU', 'Russian Federation'),
    Enumdict(186, 'RW', 'Rwanda'),
    Enumdict(187, 'BL', 'Saint Barthélemy'),
    Enumdict(188, 'SH', 'Saint Helena, Ascension and Tristan da Cunha'),
    Enumdict(189, 'KN', 'Saint Kitts and Nevis'),
    Enumdict(190, 'LC', 'Saint Lucia'),
    Enumdict(191, 'MF', 'Saint Martin (French part)'),
    Enumdict(192, 'PM', 'Saint Pierre and Miquelon'),
    Enumdict(193, 'VC', 'Saint Vincent and the Grenadines'),
    Enumdict(194, 'WS', 'Samoa'),
    Enumdict(195, 'SM', 'San Marino'),
    Enumdict(196, 'ST', 'Sao Tome and Principe'),
    Enumdict(197, 'SA', 'Saudi Arabia'),
    Enumdict(198, 'SN', 'Senegal'),
    Enumdict(199, 'RS', 'Serbia'),
    Enumdict(200, 'SC', 'Seychelles'),
    Enumdict(201, 'SL', 'Sierra Leone'),
    Enumdict(202, 'SG', 'Singapore'),
    Enumdict(203, 'SX', 'Sint Maarten (Dutch part)'),
    Enumdict(204, 'SK', 'Slovakia'),
    Enumdict(205, 'SI', 'Slovenia'),
    Enumdict(206, 'SB', 'Solomon Islands'),
    Enumdict(207, 'SO', 'Somalia'),
    Enumdict(208, 'ZA', 'South Africa'),
    Enumdict(209, 'GS', 'South Georgia and the South Sandwich Islands'),
    Enumdict(210, 'KR', 'Republic of Korea'),
    Enumdict(211, 'SS', 'South Sudan'),
    Enumdict(212, 'ES', 'Spain'),
    Enumdict(213, 'LK', 'Sri Lanka'),
    Enumdict(214, 'SD', 'Sudan'),
    Enumdict(215, 'SR', 'Suriname'),
    Enumdict(216, 'SJ', 'Svalbard and Jan Mayen'),
    Enumdict(217, 'SZ', 'Swaziland'),
    Enumdict(218, 'SE', 'Sweden'),
    Enumdict(219, 'CH', 'Switzerland'),
    Enumdict(220, 'SY', 'Syrian Arab Republic'),
    Enumdict(221, 'TW', 'Taiwan'),
    Enumdict(222, 'TJ', 'Tajikistan'),
    Enumdict(223, 'TZ', 'United Republic of Tanzania'),
    Enumdict(224, 'TH', 'Thailand'),
    Enumdict(225, 'TL', 'Timor-Leste'),
    Enumdict(226, 'TG', 'Togo'),
    Enumdict(227, 'TK', 'Tokelau'),
    Enumdict(228, 'TO', 'Tonga'),
    Enumdict(229, 'TT', 'Trinidad and Tobago'),
    Enumdict(230, 'TN', 'Tunisia'),
    Enumdict(231, 'TR', 'Turkey'),
    Enumdict(232, 'TM', 'Turkmenistan'),
    Enumdict(233, 'TC', 'Turks and Caicos Islands'),
    Enumdict(234, 'TV', 'Tuvalu'),
    Enumdict(235, 'UG', 'Uganda'),
    Enumdict(236, 'UA', 'Ukraine'),
    Enumdict(237, 'AE', 'United Arab Emirates'),
    Enumdict(238, 'GB', 'United Kingdom of Great Britain and Northern Ireland'),
    Enumdict(239, 'US', 'United States of America'),
    Enumdict(240, 'UY', 'Uruguay'),
    Enumdict(241, 'UZ', 'Uzbekistan'),
    Enumdict(242, 'VU', 'Vanuatu'),
    Enumdict(243, 'VE', 'Bolivarian Republic of Venezuela'),
    Enumdict(244, 'VN', 'Viet Nam'),
    Enumdict(245, 'WF', 'Wallis and Futuna'),
    Enumdict(246, 'EH', 'Western Sahara'),
    Enumdict(247, 'YE', 'Yemen'),
    Enumdict(248, 'ZM', 'Zambia'),
    Enumdict(249, 'ZW', 'Zimbabwe')
    )

# Timezones
TZ_enum_table = Table("tz_vocabulary",
    Base.metadata,
    Column("enum_val", Integer, primary_key=True),
    Column("enum_str", String),
    Column("enum_display_str", String)
)
# The following code is just a workaround (see above):
TZ_enum = (
    Enumdict(0, 'Africa/Abidjan', 'Africa/Abidjan'),
    Enumdict(1, 'Africa/Accra', 'Africa/Accra'),
    Enumdict(2, 'Africa/Addis_Ababa', 'Africa/Addis_Ababa'),
    Enumdict(3, 'Africa/Algiers', 'Africa/Algiers'),
    Enumdict(4, 'Africa/Asmara', 'Africa/Asmara'),
    Enumdict(5, 'Africa/Asmera', 'Africa/Asmera'),
    Enumdict(6, 'Africa/Bamako', 'Africa/Bamako'),
    Enumdict(7, 'Africa/Bangui', 'Africa/Bangui'),
    Enumdict(8, 'Africa/Banjul', 'Africa/Banjul'),
    Enumdict(9, 'Africa/Bissau', 'Africa/Bissau'),
    Enumdict(10, 'Africa/Blantyre', 'Africa/Blantyre'),
    Enumdict(11, 'Africa/Brazzaville', 'Africa/Brazzaville'),
    Enumdict(12, 'Africa/Bujumbura', 'Africa/Bujumbura'),
    Enumdict(13, 'Africa/Cairo', 'Africa/Cairo'),
    Enumdict(14, 'Africa/Casablanca', 'Africa/Casablanca'),
    Enumdict(15, 'Africa/Ceuta', 'Africa/Ceuta'),
    Enumdict(16, 'Africa/Conakry', 'Africa/Conakry'),
    Enumdict(17, 'Africa/Dakar', 'Africa/Dakar'),
    Enumdict(18, 'Africa/Dar_es_Salaam', 'Africa/Dar_es_Salaam'),
    Enumdict(19, 'Africa/Djibouti', 'Africa/Djibouti'),
    Enumdict(20, 'Africa/Douala', 'Africa/Douala'),
    Enumdict(21, 'Africa/El_Aaiun', 'Africa/El_Aaiun'),
    Enumdict(22, 'Africa/Freetown', 'Africa/Freetown'),
    Enumdict(23, 'Africa/Gaborone', 'Africa/Gaborone'),
    Enumdict(24, 'Africa/Harare', 'Africa/Harare'),
    Enumdict(25, 'Africa/Johannesburg', 'Africa/Johannesburg'),
    Enumdict(26, 'Africa/Juba', 'Africa/Juba'),
    Enumdict(27, 'Africa/Kampala', 'Africa/Kampala'),
    Enumdict(28, 'Africa/Khartoum', 'Africa/Khartoum'),
    Enumdict(29, 'Africa/Kigali', 'Africa/Kigali'),
    Enumdict(30, 'Africa/Kinshasa', 'Africa/Kinshasa'),
    Enumdict(31, 'Africa/Lagos', 'Africa/Lagos'),
    Enumdict(32, 'Africa/Libreville', 'Africa/Libreville'),
    Enumdict(33, 'Africa/Lome', 'Africa/Lome'),
    Enumdict(34, 'Africa/Luanda', 'Africa/Luanda'),
    Enumdict(35, 'Africa/Lubumbashi', 'Africa/Lubumbashi'),
    Enumdict(36, 'Africa/Lusaka', 'Africa/Lusaka'),
    Enumdict(37, 'Africa/Malabo', 'Africa/Malabo'),
    Enumdict(38, 'Africa/Maputo', 'Africa/Maputo'),
    Enumdict(39, 'Africa/Maseru', 'Africa/Maseru'),
    Enumdict(40, 'Africa/Mbabane', 'Africa/Mbabane'),
    Enumdict(41, 'Africa/Mogadishu', 'Africa/Mogadishu'),
    Enumdict(42, 'Africa/Monrovia', 'Africa/Monrovia'),
    Enumdict(43, 'Africa/Nairobi', 'Africa/Nairobi'),
    Enumdict(44, 'Africa/Ndjamena', 'Africa/Ndjamena'),
    Enumdict(45, 'Africa/Niamey', 'Africa/Niamey'),
    Enumdict(46, 'Africa/Nouakchott', 'Africa/Nouakchott'),
    Enumdict(47, 'Africa/Ouagadougou', 'Africa/Ouagadougou'),
    Enumdict(48, 'Africa/Porto-Novo', 'Africa/Porto-Novo'),
    Enumdict(49, 'Africa/Sao_Tome', 'Africa/Sao_Tome'),
    Enumdict(50, 'Africa/Timbuktu', 'Africa/Timbuktu'),
    Enumdict(51, 'Africa/Tripoli', 'Africa/Tripoli'),
    Enumdict(52, 'Africa/Tunis', 'Africa/Tunis'),
    Enumdict(53, 'Africa/Windhoek', 'Africa/Windhoek'),
    Enumdict(54, 'America/Adak', 'America/Adak'),
    Enumdict(55, 'America/Anchorage', 'America/Anchorage'),
    Enumdict(56, 'America/Anguilla', 'America/Anguilla'),
    Enumdict(57, 'America/Antigua', 'America/Antigua'),
    Enumdict(58, 'America/Araguaina', 'America/Araguaina'),
    Enumdict(59, 'America/Argentina/Buenos_Aires', 'America/Argentina/Buenos_Aires'),
    Enumdict(60, 'America/Argentina/Catamarca', 'America/Argentina/Catamarca'),
    Enumdict(61, 'America/Argentina/ComodRivadavia', 'America/Argentina/ComodRivadavia'),
    Enumdict(62, 'America/Argentina/Cordoba', 'America/Argentina/Cordoba'),
    Enumdict(63, 'America/Argentina/Jujuy', 'America/Argentina/Jujuy'),
    Enumdict(64, 'America/Argentina/La_Rioja', 'America/Argentina/La_Rioja'),
    Enumdict(65, 'America/Argentina/Mendoza', 'America/Argentina/Mendoza'),
    Enumdict(66, 'America/Argentina/Rio_Gallegos', 'America/Argentina/Rio_Gallegos'),
    Enumdict(67, 'America/Argentina/Salta', 'America/Argentina/Salta'),
    Enumdict(68, 'America/Argentina/San_Juan', 'America/Argentina/San_Juan'),
    Enumdict(69, 'America/Argentina/San_Luis', 'America/Argentina/San_Luis'),
    Enumdict(70, 'America/Argentina/Tucuman', 'America/Argentina/Tucuman'),
    Enumdict(71, 'America/Argentina/Ushuaia', 'America/Argentina/Ushuaia'),
    Enumdict(72, 'America/Aruba', 'America/Aruba'),
    Enumdict(73, 'America/Asuncion', 'America/Asuncion'),
    Enumdict(74, 'America/Atikokan', 'America/Atikokan'),
    Enumdict(75, 'America/Atka', 'America/Atka'),
    Enumdict(76, 'America/Bahia', 'America/Bahia'),
    Enumdict(77, 'America/Bahia_Banderas', 'America/Bahia_Banderas'),
    Enumdict(78, 'America/Barbados', 'America/Barbados'),
    Enumdict(79, 'America/Belem', 'America/Belem'),
    Enumdict(80, 'America/Belize', 'America/Belize'),
    Enumdict(81, 'America/Blanc-Sablon', 'America/Blanc-Sablon'),
    Enumdict(82, 'America/Boa_Vista', 'America/Boa_Vista'),
    Enumdict(83, 'America/Bogota', 'America/Bogota'),
    Enumdict(84, 'America/Boise', 'America/Boise'),
    Enumdict(85, 'America/Buenos_Aires', 'America/Buenos_Aires'),
    Enumdict(86, 'America/Cambridge_Bay', 'America/Cambridge_Bay'),
    Enumdict(87, 'America/Campo_Grande', 'America/Campo_Grande'),
    Enumdict(88, 'America/Cancun', 'America/Cancun'),
    Enumdict(89, 'America/Caracas', 'America/Caracas'),
    Enumdict(90, 'America/Catamarca', 'America/Catamarca'),
    Enumdict(91, 'America/Cayenne', 'America/Cayenne'),
    Enumdict(92, 'America/Cayman', 'America/Cayman'),
    Enumdict(93, 'America/Chicago', 'America/Chicago'),
    Enumdict(94, 'America/Chihuahua', 'America/Chihuahua'),
    Enumdict(95, 'America/Coral_Harbour', 'America/Coral_Harbour'),
    Enumdict(96, 'America/Cordoba', 'America/Cordoba'),
    Enumdict(97, 'America/Costa_Rica', 'America/Costa_Rica'),
    Enumdict(98, 'America/Creston', 'America/Creston'),
    Enumdict(99, 'America/Cuiaba', 'America/Cuiaba'),
    Enumdict(100, 'America/Curacao', 'America/Curacao'),
    Enumdict(101, 'America/Danmarkshavn', 'America/Danmarkshavn'),
    Enumdict(102, 'America/Dawson', 'America/Dawson'),
    Enumdict(103, 'America/Dawson_Creek', 'America/Dawson_Creek'),
    Enumdict(104, 'America/Denver', 'America/Denver'),
    Enumdict(105, 'America/Detroit', 'America/Detroit'),
    Enumdict(106, 'America/Dominica', 'America/Dominica'),
    Enumdict(107, 'America/Edmonton', 'America/Edmonton'),
    Enumdict(108, 'America/Eirunepe', 'America/Eirunepe'),
    Enumdict(109, 'America/El_Salvador', 'America/El_Salvador'),
    Enumdict(110, 'America/Ensenada', 'America/Ensenada'),
    Enumdict(111, 'America/Fort_Nelson', 'America/Fort_Nelson'),
    Enumdict(112, 'America/Fort_Wayne', 'America/Fort_Wayne'),
    Enumdict(113, 'America/Fortaleza', 'America/Fortaleza'),
    Enumdict(114, 'America/Glace_Bay', 'America/Glace_Bay'),
    Enumdict(115, 'America/Godthab', 'America/Godthab'),
    Enumdict(116, 'America/Goose_Bay', 'America/Goose_Bay'),
    Enumdict(117, 'America/Grand_Turk', 'America/Grand_Turk'),
    Enumdict(118, 'America/Grenada', 'America/Grenada'),
    Enumdict(119, 'America/Guadeloupe', 'America/Guadeloupe'),
    Enumdict(120, 'America/Guatemala', 'America/Guatemala'),
    Enumdict(121, 'America/Guayaquil', 'America/Guayaquil'),
    Enumdict(122, 'America/Guyana', 'America/Guyana'),
    Enumdict(123, 'America/Halifax', 'America/Halifax'),
    Enumdict(124, 'America/Havana', 'America/Havana'),
    Enumdict(125, 'America/Hermosillo', 'America/Hermosillo'),
    Enumdict(126, 'America/Indiana/Indianapolis', 'America/Indiana/Indianapolis'),
    Enumdict(127, 'America/Indiana/Knox', 'America/Indiana/Knox'),
    Enumdict(128, 'America/Indiana/Marengo', 'America/Indiana/Marengo'),
    Enumdict(129, 'America/Indiana/Petersburg', 'America/Indiana/Petersburg'),
    Enumdict(130, 'America/Indiana/Tell_City', 'America/Indiana/Tell_City'),
    Enumdict(131, 'America/Indiana/Vevay', 'America/Indiana/Vevay'),
    Enumdict(132, 'America/Indiana/Vincennes', 'America/Indiana/Vincennes'),
    Enumdict(133, 'America/Indiana/Winamac', 'America/Indiana/Winamac'),
    Enumdict(134, 'America/Indianapolis', 'America/Indianapolis'),
    Enumdict(135, 'America/Inuvik', 'America/Inuvik'),
    Enumdict(136, 'America/Iqaluit', 'America/Iqaluit'),
    Enumdict(137, 'America/Jamaica', 'America/Jamaica'),
    Enumdict(138, 'America/Jujuy', 'America/Jujuy'),
    Enumdict(139, 'America/Juneau', 'America/Juneau'),
    Enumdict(140, 'America/Kentucky/Louisville', 'America/Kentucky/Louisville'),
    Enumdict(141, 'America/Kentucky/Monticello', 'America/Kentucky/Monticello'),
    Enumdict(142, 'America/Knox_IN', 'America/Knox_IN'),
    Enumdict(143, 'America/Kralendijk', 'America/Kralendijk'),
    Enumdict(144, 'America/La_Paz', 'America/La_Paz'),
    Enumdict(145, 'America/Lima', 'America/Lima'),
    Enumdict(146, 'America/Los_Angeles', 'America/Los_Angeles'),
    Enumdict(147, 'America/Louisville', 'America/Louisville'),
    Enumdict(148, 'America/Lower_Princes', 'America/Lower_Princes'),
    Enumdict(149, 'America/Maceio', 'America/Maceio'),
    Enumdict(150, 'America/Managua', 'America/Managua'),
    Enumdict(151, 'America/Manaus', 'America/Manaus'),
    Enumdict(152, 'America/Marigot', 'America/Marigot'),
    Enumdict(153, 'America/Martinique', 'America/Martinique'),
    Enumdict(154, 'America/Matamoros', 'America/Matamoros'),
    Enumdict(155, 'America/Mazatlan', 'America/Mazatlan'),
    Enumdict(156, 'America/Mendoza', 'America/Mendoza'),
    Enumdict(157, 'America/Menominee', 'America/Menominee'),
    Enumdict(158, 'America/Merida', 'America/Merida'),
    Enumdict(159, 'America/Metlakatla', 'America/Metlakatla'),
    Enumdict(160, 'America/Mexico_City', 'America/Mexico_City'),
    Enumdict(161, 'America/Miquelon', 'America/Miquelon'),
    Enumdict(162, 'America/Moncton', 'America/Moncton'),
    Enumdict(163, 'America/Monterrey', 'America/Monterrey'),
    Enumdict(164, 'America/Montevideo', 'America/Montevideo'),
    Enumdict(165, 'America/Montreal', 'America/Montreal'),
    Enumdict(166, 'America/Montserrat', 'America/Montserrat'),
    Enumdict(167, 'America/Nassau', 'America/Nassau'),
    Enumdict(168, 'America/New_York', 'America/New_York'),
    Enumdict(169, 'America/Nipigon', 'America/Nipigon'),
    Enumdict(170, 'America/Nome', 'America/Nome'),
    Enumdict(171, 'America/Noronha', 'America/Noronha'),
    Enumdict(172, 'America/North_Dakota/Beulah', 'America/North_Dakota/Beulah'),
    Enumdict(173, 'America/North_Dakota/Center', 'America/North_Dakota/Center'),
    Enumdict(174, 'America/North_Dakota/New_Salem', 'America/North_Dakota/New_Salem'),
    Enumdict(175, 'America/Nuuk', 'America/Nuuk'),
    Enumdict(176, 'America/Ojinaga', 'America/Ojinaga'),
    Enumdict(177, 'America/Panama', 'America/Panama'),
    Enumdict(178, 'America/Pangnirtung', 'America/Pangnirtung'),
    Enumdict(179, 'America/Paramaribo', 'America/Paramaribo'),
    Enumdict(180, 'America/Phoenix', 'America/Phoenix'),
    Enumdict(181, 'America/Port-au-Prince', 'America/Port-au-Prince'),
    Enumdict(182, 'America/Port_of_Spain', 'America/Port_of_Spain'),
    Enumdict(183, 'America/Porto_Acre', 'America/Porto_Acre'),
    Enumdict(184, 'America/Porto_Velho', 'America/Porto_Velho'),
    Enumdict(185, 'America/Puerto_Rico', 'America/Puerto_Rico'),
    Enumdict(186, 'America/Punta_Arenas', 'America/Punta_Arenas'),
    Enumdict(187, 'America/Rainy_River', 'America/Rainy_River'),
    Enumdict(188, 'America/Rankin_Inlet', 'America/Rankin_Inlet'),
    Enumdict(189, 'America/Recife', 'America/Recife'),
    Enumdict(190, 'America/Regina', 'America/Regina'),
    Enumdict(191, 'America/Resolute', 'America/Resolute'),
    Enumdict(192, 'America/Rio_Branco', 'America/Rio_Branco'),
    Enumdict(193, 'America/Rosario', 'America/Rosario'),
    Enumdict(194, 'America/Santa_Isabel', 'America/Santa_Isabel'),
    Enumdict(195, 'America/Santarem', 'America/Santarem'),
    Enumdict(196, 'America/Santiago', 'America/Santiago'),
    Enumdict(197, 'America/Santo_Domingo', 'America/Santo_Domingo'),
    Enumdict(198, 'America/Sao_Paulo', 'America/Sao_Paulo'),
    Enumdict(199, 'America/Scoresbysund', 'America/Scoresbysund'),
    Enumdict(200, 'America/Shiprock', 'America/Shiprock'),
    Enumdict(201, 'America/Sitka', 'America/Sitka'),
    Enumdict(202, 'America/St_Barthelemy', 'America/St_Barthelemy'),
    Enumdict(203, 'America/St_Johns', 'America/St_Johns'),
    Enumdict(204, 'America/St_Kitts', 'America/St_Kitts'),
    Enumdict(205, 'America/St_Lucia', 'America/St_Lucia'),
    Enumdict(206, 'America/St_Thomas', 'America/St_Thomas'),
    Enumdict(207, 'America/St_Vincent', 'America/St_Vincent'),
    Enumdict(208, 'America/Swift_Current', 'America/Swift_Current'),
    Enumdict(209, 'America/Tegucigalpa', 'America/Tegucigalpa'),
    Enumdict(210, 'America/Thule', 'America/Thule'),
    Enumdict(211, 'America/Thunder_Bay', 'America/Thunder_Bay'),
    Enumdict(212, 'America/Tijuana', 'America/Tijuana'),
    Enumdict(213, 'America/Toronto', 'America/Toronto'),
    Enumdict(214, 'America/Tortola', 'America/Tortola'),
    Enumdict(215, 'America/Vancouver', 'America/Vancouver'),
    Enumdict(216, 'America/Virgin', 'America/Virgin'),
    Enumdict(217, 'America/Whitehorse', 'America/Whitehorse'),
    Enumdict(218, 'America/Winnipeg', 'America/Winnipeg'),
    Enumdict(219, 'America/Yakutat', 'America/Yakutat'),
    Enumdict(220, 'America/Yellowknife', 'America/Yellowknife'),
    Enumdict(221, 'Antarctica/Casey', 'Antarctica/Casey'),
    Enumdict(222, 'Antarctica/Davis', 'Antarctica/Davis'),
    Enumdict(223, 'Antarctica/DumontDUrville', 'Antarctica/DumontDUrville'),
    Enumdict(224, 'Antarctica/Macquarie', 'Antarctica/Macquarie'),
    Enumdict(225, 'Antarctica/Mawson', 'Antarctica/Mawson'),
    Enumdict(226, 'Antarctica/McMurdo', 'Antarctica/McMurdo'),
    Enumdict(227, 'Antarctica/Palmer', 'Antarctica/Palmer'),
    Enumdict(228, 'Antarctica/Rothera', 'Antarctica/Rothera'),
    Enumdict(229, 'Antarctica/South_Pole', 'Antarctica/South_Pole'),
    Enumdict(230, 'Antarctica/Syowa', 'Antarctica/Syowa'),
    Enumdict(231, 'Antarctica/Troll', 'Antarctica/Troll'),
    Enumdict(232, 'Antarctica/Vostok', 'Antarctica/Vostok'),
    Enumdict(233, 'Arctic/Longyearbyen', 'Arctic/Longyearbyen'),
    Enumdict(234, 'Asia/Aden', 'Asia/Aden'),
    Enumdict(235, 'Asia/Almaty', 'Asia/Almaty'),
    Enumdict(236, 'Asia/Amman', 'Asia/Amman'),
    Enumdict(237, 'Asia/Anadyr', 'Asia/Anadyr'),
    Enumdict(238, 'Asia/Aqtau', 'Asia/Aqtau'),
    Enumdict(239, 'Asia/Aqtobe', 'Asia/Aqtobe'),
    Enumdict(240, 'Asia/Ashgabat', 'Asia/Ashgabat'),
    Enumdict(241, 'Asia/Ashkhabad', 'Asia/Ashkhabad'),
    Enumdict(242, 'Asia/Atyrau', 'Asia/Atyrau'),
    Enumdict(243, 'Asia/Baghdad', 'Asia/Baghdad'),
    Enumdict(244, 'Asia/Bahrain', 'Asia/Bahrain'),
    Enumdict(245, 'Asia/Baku', 'Asia/Baku'),
    Enumdict(246, 'Asia/Bangkok', 'Asia/Bangkok'),
    Enumdict(247, 'Asia/Barnaul', 'Asia/Barnaul'),
    Enumdict(248, 'Asia/Beirut', 'Asia/Beirut'),
    Enumdict(249, 'Asia/Bishkek', 'Asia/Bishkek'),
    Enumdict(250, 'Asia/Brunei', 'Asia/Brunei'),
    Enumdict(251, 'Asia/Calcutta', 'Asia/Calcutta'),
    Enumdict(252, 'Asia/Chita', 'Asia/Chita'),
    Enumdict(253, 'Asia/Choibalsan', 'Asia/Choibalsan'),
    Enumdict(254, 'Asia/Chongqing', 'Asia/Chongqing'),
    Enumdict(255, 'Asia/Chungking', 'Asia/Chungking'),
    Enumdict(256, 'Asia/Colombo', 'Asia/Colombo'),
    Enumdict(257, 'Asia/Dacca', 'Asia/Dacca'),
    Enumdict(258, 'Asia/Damascus', 'Asia/Damascus'),
    Enumdict(259, 'Asia/Dhaka', 'Asia/Dhaka'),
    Enumdict(260, 'Asia/Dili', 'Asia/Dili'),
    Enumdict(261, 'Asia/Dubai', 'Asia/Dubai'),
    Enumdict(262, 'Asia/Dushanbe', 'Asia/Dushanbe'),
    Enumdict(263, 'Asia/Famagusta', 'Asia/Famagusta'),
    Enumdict(264, 'Asia/Gaza', 'Asia/Gaza'),
    Enumdict(265, 'Asia/Harbin', 'Asia/Harbin'),
    Enumdict(266, 'Asia/Hebron', 'Asia/Hebron'),
    Enumdict(267, 'Asia/Ho_Chi_Minh', 'Asia/Ho_Chi_Minh'),
    Enumdict(268, 'Asia/Hong_Kong', 'Asia/Hong_Kong'),
    Enumdict(269, 'Asia/Hovd', 'Asia/Hovd'),
    Enumdict(270, 'Asia/Irkutsk', 'Asia/Irkutsk'),
    Enumdict(271, 'Asia/Istanbul', 'Asia/Istanbul'),
    Enumdict(272, 'Asia/Jakarta', 'Asia/Jakarta'),
    Enumdict(273, 'Asia/Jayapura', 'Asia/Jayapura'),
    Enumdict(274, 'Asia/Jerusalem', 'Asia/Jerusalem'),
    Enumdict(275, 'Asia/Kabul', 'Asia/Kabul'),
    Enumdict(276, 'Asia/Kamchatka', 'Asia/Kamchatka'),
    Enumdict(277, 'Asia/Karachi', 'Asia/Karachi'),
    Enumdict(278, 'Asia/Kashgar', 'Asia/Kashgar'),
    Enumdict(279, 'Asia/Kathmandu', 'Asia/Kathmandu'),
    Enumdict(280, 'Asia/Katmandu', 'Asia/Katmandu'),
    Enumdict(281, 'Asia/Khandyga', 'Asia/Khandyga'),
    Enumdict(282, 'Asia/Kolkata', 'Asia/Kolkata'),
    Enumdict(283, 'Asia/Krasnoyarsk', 'Asia/Krasnoyarsk'),
    Enumdict(284, 'Asia/Kuala_Lumpur', 'Asia/Kuala_Lumpur'),
    Enumdict(285, 'Asia/Kuching', 'Asia/Kuching'),
    Enumdict(286, 'Asia/Kuwait', 'Asia/Kuwait'),
    Enumdict(287, 'Asia/Macao', 'Asia/Macao'),
    Enumdict(288, 'Asia/Macau', 'Asia/Macau'),
    Enumdict(289, 'Asia/Magadan', 'Asia/Magadan'),
    Enumdict(290, 'Asia/Makassar', 'Asia/Makassar'),
    Enumdict(291, 'Asia/Manila', 'Asia/Manila'),
    Enumdict(292, 'Asia/Muscat', 'Asia/Muscat'),
    Enumdict(293, 'Asia/Nicosia', 'Asia/Nicosia'),
    Enumdict(294, 'Asia/Novokuznetsk', 'Asia/Novokuznetsk'),
    Enumdict(295, 'Asia/Novosibirsk', 'Asia/Novosibirsk'),
    Enumdict(296, 'Asia/Omsk', 'Asia/Omsk'),
    Enumdict(297, 'Asia/Oral', 'Asia/Oral'),
    Enumdict(298, 'Asia/Phnom_Penh', 'Asia/Phnom_Penh'),
    Enumdict(299, 'Asia/Pontianak', 'Asia/Pontianak'),
    Enumdict(300, 'Asia/Pyongyang', 'Asia/Pyongyang'),
    Enumdict(301, 'Asia/Qatar', 'Asia/Qatar'),
    Enumdict(302, 'Asia/Qostanay', 'Asia/Qostanay'),
    Enumdict(303, 'Asia/Qyzylorda', 'Asia/Qyzylorda'),
    Enumdict(304, 'Asia/Rangoon', 'Asia/Rangoon'),
    Enumdict(305, 'Asia/Riyadh', 'Asia/Riyadh'),
    Enumdict(306, 'Asia/Saigon', 'Asia/Saigon'),
    Enumdict(307, 'Asia/Sakhalin', 'Asia/Sakhalin'),
    Enumdict(308, 'Asia/Samarkand', 'Asia/Samarkand'),
    Enumdict(309, 'Asia/Seoul', 'Asia/Seoul'),
    Enumdict(310, 'Asia/Shanghai', 'Asia/Shanghai'),
    Enumdict(311, 'Asia/Singapore', 'Asia/Singapore'),
    Enumdict(312, 'Asia/Srednekolymsk', 'Asia/Srednekolymsk'),
    Enumdict(313, 'Asia/Taipei', 'Asia/Taipei'),
    Enumdict(314, 'Asia/Tashkent', 'Asia/Tashkent'),
    Enumdict(315, 'Asia/Tbilisi', 'Asia/Tbilisi'),
    Enumdict(316, 'Asia/Tehran', 'Asia/Tehran'),
    Enumdict(317, 'Asia/Tel_Aviv', 'Asia/Tel_Aviv'),
    Enumdict(318, 'Asia/Thimbu', 'Asia/Thimbu'),
    Enumdict(319, 'Asia/Thimphu', 'Asia/Thimphu'),
    Enumdict(320, 'Asia/Tokyo', 'Asia/Tokyo'),
    Enumdict(321, 'Asia/Tomsk', 'Asia/Tomsk'),
    Enumdict(322, 'Asia/Ujung_Pandang', 'Asia/Ujung_Pandang'),
    Enumdict(323, 'Asia/Ulaanbaatar', 'Asia/Ulaanbaatar'),
    Enumdict(324, 'Asia/Ulan_Bator', 'Asia/Ulan_Bator'),
    Enumdict(325, 'Asia/Urumqi', 'Asia/Urumqi'),
    Enumdict(326, 'Asia/Ust-Nera', 'Asia/Ust-Nera'),
    Enumdict(327, 'Asia/Vientiane', 'Asia/Vientiane'),
    Enumdict(328, 'Asia/Vladivostok', 'Asia/Vladivostok'),
    Enumdict(329, 'Asia/Yakutsk', 'Asia/Yakutsk'),
    Enumdict(330, 'Asia/Yangon', 'Asia/Yangon'),
    Enumdict(331, 'Asia/Yekaterinburg', 'Asia/Yekaterinburg'),
    Enumdict(332, 'Asia/Yerevan', 'Asia/Yerevan'),
    Enumdict(333, 'Atlantic/Azores', 'Atlantic/Azores'),
    Enumdict(334, 'Atlantic/Bermuda', 'Atlantic/Bermuda'),
    Enumdict(335, 'Atlantic/Canary', 'Atlantic/Canary'),
    Enumdict(336, 'Atlantic/Cape_Verde', 'Atlantic/Cape_Verde'),
    Enumdict(337, 'Atlantic/Faeroe', 'Atlantic/Faeroe'),
    Enumdict(338, 'Atlantic/Faroe', 'Atlantic/Faroe'),
    Enumdict(339, 'Atlantic/Jan_Mayen', 'Atlantic/Jan_Mayen'),
    Enumdict(340, 'Atlantic/Madeira', 'Atlantic/Madeira'),
    Enumdict(341, 'Atlantic/Reykjavik', 'Atlantic/Reykjavik'),
    Enumdict(342, 'Atlantic/South_Georgia', 'Atlantic/South_Georgia'),
    Enumdict(343, 'Atlantic/St_Helena', 'Atlantic/St_Helena'),
    Enumdict(344, 'Atlantic/Stanley', 'Atlantic/Stanley'),
    Enumdict(345, 'Australia/ACT', 'Australia/ACT'),
    Enumdict(346, 'Australia/Adelaide', 'Australia/Adelaide'),
    Enumdict(347, 'Australia/Brisbane', 'Australia/Brisbane'),
    Enumdict(348, 'Australia/Broken_Hill', 'Australia/Broken_Hill'),
    Enumdict(349, 'Australia/Canberra', 'Australia/Canberra'),
    Enumdict(350, 'Australia/Currie', 'Australia/Currie'),
    Enumdict(351, 'Australia/Darwin', 'Australia/Darwin'),
    Enumdict(352, 'Australia/Eucla', 'Australia/Eucla'),
    Enumdict(353, 'Australia/Hobart', 'Australia/Hobart'),
    Enumdict(354, 'Australia/LHI', 'Australia/LHI'),
    Enumdict(355, 'Australia/Lindeman', 'Australia/Lindeman'),
    Enumdict(356, 'Australia/Lord_Howe', 'Australia/Lord_Howe'),
    Enumdict(357, 'Australia/Melbourne', 'Australia/Melbourne'),
    Enumdict(358, 'Australia/NSW', 'Australia/NSW'),
    Enumdict(359, 'Australia/North', 'Australia/North'),
    Enumdict(360, 'Australia/Perth', 'Australia/Perth'),
    Enumdict(361, 'Australia/Queensland', 'Australia/Queensland'),
    Enumdict(362, 'Australia/South', 'Australia/South'),
    Enumdict(363, 'Australia/Sydney', 'Australia/Sydney'),
    Enumdict(364, 'Australia/Tasmania', 'Australia/Tasmania'),
    Enumdict(365, 'Australia/Victoria', 'Australia/Victoria'),
    Enumdict(366, 'Australia/West', 'Australia/West'),
    Enumdict(367, 'Australia/Yancowinna', 'Australia/Yancowinna'),
    Enumdict(368, 'Brazil/Acre', 'Brazil/Acre'),
    Enumdict(369, 'Brazil/DeNoronha', 'Brazil/DeNoronha'),
    Enumdict(370, 'Brazil/East', 'Brazil/East'),
    Enumdict(371, 'Brazil/West', 'Brazil/West'),
    Enumdict(372, 'CET', 'CET'),
    Enumdict(373, 'CST6CDT', 'CST6CDT'),
    Enumdict(374, 'Canada/Atlantic', 'Canada/Atlantic'),
    Enumdict(375, 'Canada/Central', 'Canada/Central'),
    Enumdict(376, 'Canada/Eastern', 'Canada/Eastern'),
    Enumdict(377, 'Canada/Mountain', 'Canada/Mountain'),
    Enumdict(378, 'Canada/Newfoundland', 'Canada/Newfoundland'),
    Enumdict(379, 'Canada/Pacific', 'Canada/Pacific'),
    Enumdict(380, 'Canada/Saskatchewan', 'Canada/Saskatchewan'),
    Enumdict(381, 'Canada/Yukon', 'Canada/Yukon'),
    Enumdict(382, 'Chile/Continental', 'Chile/Continental'),
    Enumdict(383, 'Chile/EasterIsland', 'Chile/EasterIsland'),
    Enumdict(384, 'Cuba', 'Cuba'),
    Enumdict(385, 'EET', 'EET'),
    Enumdict(386, 'EST', 'EST'),
    Enumdict(387, 'EST5EDT', 'EST5EDT'),
    Enumdict(388, 'Egypt', 'Egypt'),
    Enumdict(389, 'Eire', 'Eire'),
    Enumdict(390, 'Etc/GMT', 'Etc/GMT'),
    Enumdict(391, 'Etc/GMT+0', 'Etc/GMT+0'),
    Enumdict(392, 'Etc/GMT+1', 'Etc/GMT+1'),
    Enumdict(393, 'Etc/GMT+10', 'Etc/GMT+10'),
    Enumdict(394, 'Etc/GMT+11', 'Etc/GMT+11'),
    Enumdict(395, 'Etc/GMT+12', 'Etc/GMT+12'),
    Enumdict(396, 'Etc/GMT+2', 'Etc/GMT+2'),
    Enumdict(397, 'Etc/GMT+3', 'Etc/GMT+3'),
    Enumdict(398, 'Etc/GMT+4', 'Etc/GMT+4'),
    Enumdict(399, 'Etc/GMT+5', 'Etc/GMT+5'),
    Enumdict(400, 'Etc/GMT+6', 'Etc/GMT+6'),
    Enumdict(401, 'Etc/GMT+7', 'Etc/GMT+7'),
    Enumdict(402, 'Etc/GMT+8', 'Etc/GMT+8'),
    Enumdict(403, 'Etc/GMT+9', 'Etc/GMT+9'),
    Enumdict(404, 'Etc/GMT-0', 'Etc/GMT-0'),
    Enumdict(405, 'Etc/GMT-1', 'Etc/GMT-1'),
    Enumdict(406, 'Etc/GMT-10', 'Etc/GMT-10'),
    Enumdict(407, 'Etc/GMT-11', 'Etc/GMT-11'),
    Enumdict(408, 'Etc/GMT-12', 'Etc/GMT-12'),
    Enumdict(409, 'Etc/GMT-13', 'Etc/GMT-13'),
    Enumdict(410, 'Etc/GMT-14', 'Etc/GMT-14'),
    Enumdict(411, 'Etc/GMT-2', 'Etc/GMT-2'),
    Enumdict(412, 'Etc/GMT-3', 'Etc/GMT-3'),
    Enumdict(413, 'Etc/GMT-4', 'Etc/GMT-4'),
    Enumdict(414, 'Etc/GMT-5', 'Etc/GMT-5'),
    Enumdict(415, 'Etc/GMT-6', 'Etc/GMT-6'),
    Enumdict(416, 'Etc/GMT-7', 'Etc/GMT-7'),
    Enumdict(417, 'Etc/GMT-8', 'Etc/GMT-8'),
    Enumdict(418, 'Etc/GMT-9', 'Etc/GMT-9'),
    Enumdict(419, 'Etc/GMT0', 'Etc/GMT0'),
    Enumdict(420, 'Etc/Greenwich', 'Etc/Greenwich'),
    Enumdict(421, 'Etc/UCT', 'Etc/UCT'),
    Enumdict(422, 'Etc/UTC', 'Etc/UTC'),
    Enumdict(423, 'Etc/Universal', 'Etc/Universal'),
    Enumdict(424, 'Etc/Zulu', 'Etc/Zulu'),
    Enumdict(425, 'Europe/Amsterdam', 'Europe/Amsterdam'),
    Enumdict(426, 'Europe/Andorra', 'Europe/Andorra'),
    Enumdict(427, 'Europe/Astrakhan', 'Europe/Astrakhan'),
    Enumdict(428, 'Europe/Athens', 'Europe/Athens'),
    Enumdict(429, 'Europe/Belfast', 'Europe/Belfast'),
    Enumdict(430, 'Europe/Belgrade', 'Europe/Belgrade'),
    Enumdict(431, 'Europe/Berlin', 'Europe/Berlin'),
    Enumdict(432, 'Europe/Bratislava', 'Europe/Bratislava'),
    Enumdict(433, 'Europe/Brussels', 'Europe/Brussels'),
    Enumdict(434, 'Europe/Bucharest', 'Europe/Bucharest'),
    Enumdict(435, 'Europe/Budapest', 'Europe/Budapest'),
    Enumdict(436, 'Europe/Busingen', 'Europe/Busingen'),
    Enumdict(437, 'Europe/Chisinau', 'Europe/Chisinau'),
    Enumdict(438, 'Europe/Copenhagen', 'Europe/Copenhagen'),
    Enumdict(439, 'Europe/Dublin', 'Europe/Dublin'),
    Enumdict(440, 'Europe/Gibraltar', 'Europe/Gibraltar'),
    Enumdict(441, 'Europe/Guernsey', 'Europe/Guernsey'),
    Enumdict(442, 'Europe/Helsinki', 'Europe/Helsinki'),
    Enumdict(443, 'Europe/Isle_of_Man', 'Europe/Isle_of_Man'),
    Enumdict(444, 'Europe/Istanbul', 'Europe/Istanbul'),
    Enumdict(445, 'Europe/Jersey', 'Europe/Jersey'),
    Enumdict(446, 'Europe/Kaliningrad', 'Europe/Kaliningrad'),
    Enumdict(447, 'Europe/Kiev', 'Europe/Kiev'),
    Enumdict(448, 'Europe/Kirov', 'Europe/Kirov'),
    Enumdict(449, 'Europe/Lisbon', 'Europe/Lisbon'),
    Enumdict(450, 'Europe/Ljubljana', 'Europe/Ljubljana'),
    Enumdict(451, 'Europe/London', 'Europe/London'),
    Enumdict(452, 'Europe/Luxembourg', 'Europe/Luxembourg'),
    Enumdict(453, 'Europe/Madrid', 'Europe/Madrid'),
    Enumdict(454, 'Europe/Malta', 'Europe/Malta'),
    Enumdict(455, 'Europe/Mariehamn', 'Europe/Mariehamn'),
    Enumdict(456, 'Europe/Minsk', 'Europe/Minsk'),
    Enumdict(457, 'Europe/Monaco', 'Europe/Monaco'),
    Enumdict(458, 'Europe/Moscow', 'Europe/Moscow'),
    Enumdict(459, 'Europe/Nicosia', 'Europe/Nicosia'),
    Enumdict(460, 'Europe/Oslo', 'Europe/Oslo'),
    Enumdict(461, 'Europe/Paris', 'Europe/Paris'),
    Enumdict(462, 'Europe/Podgorica', 'Europe/Podgorica'),
    Enumdict(463, 'Europe/Prague', 'Europe/Prague'),
    Enumdict(464, 'Europe/Riga', 'Europe/Riga'),
    Enumdict(465, 'Europe/Rome', 'Europe/Rome'),
    Enumdict(466, 'Europe/Samara', 'Europe/Samara'),
    Enumdict(467, 'Europe/San_Marino', 'Europe/San_Marino'),
    Enumdict(468, 'Europe/Sarajevo', 'Europe/Sarajevo'),
    Enumdict(469, 'Europe/Saratov', 'Europe/Saratov'),
    Enumdict(470, 'Europe/Simferopol', 'Europe/Simferopol'),
    Enumdict(471, 'Europe/Skopje', 'Europe/Skopje'),
    Enumdict(472, 'Europe/Sofia', 'Europe/Sofia'),
    Enumdict(473, 'Europe/Stockholm', 'Europe/Stockholm'),
    Enumdict(474, 'Europe/Tallinn', 'Europe/Tallinn'),
    Enumdict(475, 'Europe/Tirane', 'Europe/Tirane'),
    Enumdict(476, 'Europe/Tiraspol', 'Europe/Tiraspol'),
    Enumdict(477, 'Europe/Ulyanovsk', 'Europe/Ulyanovsk'),
    Enumdict(478, 'Europe/Uzhgorod', 'Europe/Uzhgorod'),
    Enumdict(479, 'Europe/Vaduz', 'Europe/Vaduz'),
    Enumdict(480, 'Europe/Vatican', 'Europe/Vatican'),
    Enumdict(481, 'Europe/Vienna', 'Europe/Vienna'),
    Enumdict(482, 'Europe/Vilnius', 'Europe/Vilnius'),
    Enumdict(483, 'Europe/Volgograd', 'Europe/Volgograd'),
    Enumdict(484, 'Europe/Warsaw', 'Europe/Warsaw'),
    Enumdict(485, 'Europe/Zagreb', 'Europe/Zagreb'),
    Enumdict(486, 'Europe/Zaporozhye', 'Europe/Zaporozhye'),
    Enumdict(487, 'Europe/Zurich', 'Europe/Zurich'),
    Enumdict(488, 'GB', 'GB'),
    Enumdict(489, 'GB-Eire', 'GB-Eire'),
    Enumdict(490, 'GMT', 'GMT'),
    Enumdict(491, 'GMT+0', 'GMT+0'),
    Enumdict(492, 'GMT-0', 'GMT-0'),
    Enumdict(493, 'GMT0', 'GMT0'),
    Enumdict(494, 'Greenwich', 'Greenwich'),
    Enumdict(495, 'HST', 'HST'),
    Enumdict(496, 'Hongkong', 'Hongkong'),
    Enumdict(497, 'Iceland', 'Iceland'),
    Enumdict(498, 'Indian/Antananarivo', 'Indian/Antananarivo'),
    Enumdict(499, 'Indian/Chagos', 'Indian/Chagos'),
    Enumdict(500, 'Indian/Christmas', 'Indian/Christmas'),
    Enumdict(501, 'Indian/Cocos', 'Indian/Cocos'),
    Enumdict(502, 'Indian/Comoro', 'Indian/Comoro'),
    Enumdict(503, 'Indian/Kerguelen', 'Indian/Kerguelen'),
    Enumdict(504, 'Indian/Mahe', 'Indian/Mahe'),
    Enumdict(505, 'Indian/Maldives', 'Indian/Maldives'),
    Enumdict(506, 'Indian/Mauritius', 'Indian/Mauritius'),
    Enumdict(507, 'Indian/Mayotte', 'Indian/Mayotte'),
    Enumdict(508, 'Indian/Reunion', 'Indian/Reunion'),
    Enumdict(509, 'Iran', 'Iran'),
    Enumdict(510, 'Israel', 'Israel'),
    Enumdict(511, 'Jamaica', 'Jamaica'),
    Enumdict(512, 'Japan', 'Japan'),
    Enumdict(513, 'Kwajalein', 'Kwajalein'),
    Enumdict(514, 'Libya', 'Libya'),
    Enumdict(515, 'MET', 'MET'),
    Enumdict(516, 'MST', 'MST'),
    Enumdict(517, 'MST7MDT', 'MST7MDT'),
    Enumdict(518, 'Mexico/BajaNorte', 'Mexico/BajaNorte'),
    Enumdict(519, 'Mexico/BajaSur', 'Mexico/BajaSur'),
    Enumdict(520, 'Mexico/General', 'Mexico/General'),
    Enumdict(521, 'NZ', 'NZ'),
    Enumdict(522, 'NZ-CHAT', 'NZ-CHAT'),
    Enumdict(523, 'Navajo', 'Navajo'),
    Enumdict(524, 'PRC', 'PRC'),
    Enumdict(525, 'PST8PDT', 'PST8PDT'),
    Enumdict(526, 'Pacific/Apia', 'Pacific/Apia'),
    Enumdict(527, 'Pacific/Auckland', 'Pacific/Auckland'),
    Enumdict(528, 'Pacific/Bougainville', 'Pacific/Bougainville'),
    Enumdict(529, 'Pacific/Chatham', 'Pacific/Chatham'),
    Enumdict(530, 'Pacific/Chuuk', 'Pacific/Chuuk'),
    Enumdict(531, 'Pacific/Easter', 'Pacific/Easter'),
    Enumdict(532, 'Pacific/Efate', 'Pacific/Efate'),
    Enumdict(533, 'Pacific/Enderbury', 'Pacific/Enderbury'),
    Enumdict(534, 'Pacific/Fakaofo', 'Pacific/Fakaofo'),
    Enumdict(535, 'Pacific/Fiji', 'Pacific/Fiji'),
    Enumdict(536, 'Pacific/Funafuti', 'Pacific/Funafuti'),
    Enumdict(537, 'Pacific/Galapagos', 'Pacific/Galapagos'),
    Enumdict(538, 'Pacific/Gambier', 'Pacific/Gambier'),
    Enumdict(539, 'Pacific/Guadalcanal', 'Pacific/Guadalcanal'),
    Enumdict(540, 'Pacific/Guam', 'Pacific/Guam'),
    Enumdict(541, 'Pacific/Honolulu', 'Pacific/Honolulu'),
    Enumdict(542, 'Pacific/Johnston', 'Pacific/Johnston'),
    Enumdict(543, 'Pacific/Kiritimati', 'Pacific/Kiritimati'),
    Enumdict(544, 'Pacific/Kosrae', 'Pacific/Kosrae'),
    Enumdict(545, 'Pacific/Kwajalein', 'Pacific/Kwajalein'),
    Enumdict(546, 'Pacific/Majuro', 'Pacific/Majuro'),
    Enumdict(547, 'Pacific/Marquesas', 'Pacific/Marquesas'),
    Enumdict(548, 'Pacific/Midway', 'Pacific/Midway'),
    Enumdict(549, 'Pacific/Nauru', 'Pacific/Nauru'),
    Enumdict(550, 'Pacific/Niue', 'Pacific/Niue'),
    Enumdict(551, 'Pacific/Norfolk', 'Pacific/Norfolk'),
    Enumdict(552, 'Pacific/Noumea', 'Pacific/Noumea'),
    Enumdict(553, 'Pacific/Pago_Pago', 'Pacific/Pago_Pago'),
    Enumdict(554, 'Pacific/Palau', 'Pacific/Palau'),
    Enumdict(555, 'Pacific/Pitcairn', 'Pacific/Pitcairn'),
    Enumdict(556, 'Pacific/Pohnpei', 'Pacific/Pohnpei'),
    Enumdict(557, 'Pacific/Ponape', 'Pacific/Ponape'),
    Enumdict(558, 'Pacific/Port_Moresby', 'Pacific/Port_Moresby'),
    Enumdict(559, 'Pacific/Rarotonga', 'Pacific/Rarotonga'),
    Enumdict(560, 'Pacific/Saipan', 'Pacific/Saipan'),
    Enumdict(561, 'Pacific/Samoa', 'Pacific/Samoa'),
    Enumdict(562, 'Pacific/Tahiti', 'Pacific/Tahiti'),
    Enumdict(563, 'Pacific/Tarawa', 'Pacific/Tarawa'),
    Enumdict(564, 'Pacific/Tongatapu', 'Pacific/Tongatapu'),
    Enumdict(565, 'Pacific/Truk', 'Pacific/Truk'),
    Enumdict(566, 'Pacific/Wake', 'Pacific/Wake'),
    Enumdict(567, 'Pacific/Wallis', 'Pacific/Wallis'),
    Enumdict(568, 'Pacific/Yap', 'Pacific/Yap'),
    Enumdict(569, 'Poland', 'Poland'),
    Enumdict(570, 'Portugal', 'Portugal'),
    Enumdict(571, 'ROC', 'ROC'),
    Enumdict(572, 'ROK', 'ROK'),
    Enumdict(573, 'Singapore', 'Singapore'),
    Enumdict(574, 'Turkey', 'Turkey'),
    Enumdict(575, 'UCT', 'UCT'),
    Enumdict(576, 'US/Alaska', 'US/Alaska'),
    Enumdict(577, 'US/Aleutian', 'US/Aleutian'),
    Enumdict(578, 'US/Arizona', 'US/Arizona'),
    Enumdict(579, 'US/Central', 'US/Central'),
    Enumdict(580, 'US/East-Indiana', 'US/East-Indiana'),
    Enumdict(581, 'US/Eastern', 'US/Eastern'),
    Enumdict(582, 'US/Hawaii', 'US/Hawaii'),
    Enumdict(583, 'US/Indiana-Starke', 'US/Indiana-Starke'),
    Enumdict(584, 'US/Michigan', 'US/Michigan'),
    Enumdict(585, 'US/Mountain', 'US/Mountain'),
    Enumdict(586, 'US/Pacific', 'US/Pacific'),
    Enumdict(587, 'US/Samoa', 'US/Samoa'),
    Enumdict(588, 'UTC', 'UTC'),
    Enumdict(589, 'Universal', 'Universal'),
    Enumdict(590, 'W-SU', 'W-SU'),
    Enumdict(591, 'WET', 'WET'),
    Enumdict(592, 'Zulu', 'Zulu')
    )

